(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    130270,       4267]*)
(*NotebookOutlinePosition[    156322,       5222]*)
(*  CellTagsIndexPosition[    156278,       5218]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Automatic Report Generation", "Title"],

Cell["\<\
Jon McLoone
Wolfram Research Europe\
\>", "Author"],

Cell[TextData[{
  "This tutorial is designed to equip you with the basic tools for \
programming ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to create reports automatically. The ability to program in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will be extremely important to take advantage of the material and is \
assumed.\n\nOur aim is to have a program send output, ready formatted and \
styled to a notebook so that the user has a complete report to read or share \
without further manual intervention. Lets start with the first of those \
requirements."
}], "Text"],

Cell[CellGroupData[{

Cell["Returning data", "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Output"
}], "Subsubsection"],

Cell[TextData[{
  "Our first step is to get ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to send information back to the notebook. Anyone who uses ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " interactively knows that it will return a result at the end of the \
calculation. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(1 + 1\)], "Input"],

Cell[BoxData[
    \(2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "However, there is only one result returned for each time the user requests \
an evaluation and we need to be able to tell ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to send back several pieces of data during a single evaluation process. \
For example the following command does four such operations but does not \
return any of them."
}], "Text"],

Cell[BoxData[
    \(Do[i + 1, {i, 4}]\)], "Input"],

Cell["The simplest approach is with StylePrint.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using StylePrint to return output", "Subsubsection"],

Cell["\<\
Every time that StylePrint is called within the calculation, a result is \
returned into a separate cell.\
\>", "Text"],

Cell[BoxData[
    \(Do[StylePrint[i + 1], {i, 4}]\)], "Input"],

Cell["StylePrint does not return any output to the kernel.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[StylePrint[i + 1], {i, 4}]\)], "Input"],

Cell[BoxData[
    \({Null, Null, Null, Null}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Returning images", "Subsubsection"],

Cell["Every graphics function will, by default,  return an image", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[Sin[x], {x, 0, 6}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.15873 0.309016 0.294303 [
[.18254 .29652 -3 -9 ]
[.18254 .29652 3 0 ]
[.34127 .29652 -3 -9 ]
[.34127 .29652 3 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.18254 .30902 m
.18254 .31527 L
s
[(1)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(2)] .34127 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(3)] .5 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(4)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(5)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(6)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .37994 L
.10458 .45239 L
.14415 .51137 L
.18221 .55633 L
.20178 .57407 L
.22272 .58859 L
.23293 .59393 L
.23832 .59626 L
.24402 .59838 L
.24901 .59992 L
.25449 .60129 L
.2569 .60178 L
.25949 .60223 L
.26194 .60259 L
.26416 .60285 L
.2667 .60308 L
.26809 .60317 L
.2694 .60324 L
.27062 .60328 L
.27174 .60331 L
.27297 .60332 L
.27427 .60331 L
.27558 .60328 L
.27632 .60326 L
.27699 .60323 L
.27829 .60316 L
.27952 .60308 L
.28229 .60283 L
.2853 .60246 L
.29036 .60159 L
.29573 .60034 L
.30539 .59727 L
.31476 .59326 L
.32486 .58784 L
.34314 .57517 L
.36318 .55723 L
.38428 .53408 L
.42239 .48254 L
.46295 .41682 L
.50199 .34689 L
.54349 .27017 L
.58347 .19869 L
.62194 .13644 L
.66286 .08136 L
.68321 .05938 L
.70226 .04251 L
.72052 .02994 L
.73078 .02449 L
.74015 .02055 L
Mistroke
.74493 .01892 L
.75002 .01748 L
.75442 .01648 L
.75917 .01565 L
.76209 .01526 L
.76337 .01513 L
.76478 .015 L
.76602 .01491 L
.76734 .01483 L
.76808 .01479 L
.76875 .01477 L
.77005 .01473 L
.77131 .01472 L
.77248 .01472 L
.77376 .01474 L
.77441 .01475 L
.77512 .01478 L
.77631 .01483 L
.77759 .01491 L
.77991 .0151 L
.78231 .01536 L
.78488 .01571 L
.7895 .01654 L
.795 .01785 L
.79999 .01934 L
.81085 .02357 L
.8211 .02879 L
.84115 .04236 L
.85962 .05861 L
.89907 .10435 L
.93701 .16024 L
.97619 .22678 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooo8Ol00?oo8Ol00?oo8Ol00?oo8Ol00?oo
8Ol00?oo8Ol001_o00<0ool0ool3o`006ol00`3oo`3oo`?o000Co`D00ol00`3oo`3oo`?o000Eo`03
0?oo00?o00<0ool0ool3o`003ol300?o00<0ool00ol20;oo300ho`005Ol00`3oo`03o`030?oo0;[o
100<o`<0=Ol001Go00<0ool00ol00`3oo`2io`030?oo017o0`0bo`005?l200Go00<0ool0]ol201Oo
0P0`o`006ol00`3oo`2fo`030?oo01Wo00<0ool0;Ol001_o00<0ool0]?l201go0P0]o`006ol00`3o
o`2bo`808Ol00`3oo`0Zo`006ol00`3oo`2ao`030?oo02;o00<0ool0:Ol001_o0P2ao`030?oo02Co
00<0ool0:?l001_o00<0ool0[ol00`3oo`0Vo`80:?l001_o00<0ool0[_l00`3oo`0Yo`030?oo02Go
000Ko`030?oo0:go00<0ool0:ol00`3oo`0To`006ol00`3oo`2/o`030?oo02go00<0ool08ol001_o
00<0ool0Zol00`3oo`0_o`030?oo02;o000Ko`030?oo0:[o00<0ool0<Ol00`3oo`0Qo`006ol20:[o
00<0ool0<_l00`3oo`0Qo`006ol00`3oo`2Xo`030?oo03Co00<0ool08?l001_o00<0ool0Yol00`3o
o`0fo`030?oo01oo000Ko`030?oo0:Ko00<0ool0>?l00`3oo`0No`006ol00`3oo`2Vo`030?oo03Wo
00<0ool07Ol001_o00<0ool0YOl00`3oo`0ko`030?oo01co000Ko`030?oo0:Co00<0ool0??l00`3o
o`0Lo`006ol00`3oo`2So`030?oo03ko00<0ool06ol001_o0P2To`030?oo03oo00<0ool06_l001_o
00<0ool0X_l00`3oo`11o`030?oo01Wo000Ko`030?oo0:7o00<0ool0@ol00`3oo`0Ho`006ol00`3o
o`2Po`030?oo04Co00<0ool06?l001_o00<0ool0X?l00`3oo`15o`030?oo01Oo000Ko`030?oo09oo
00<0ool0Aol00`3oo`0Fo`006ol00`3oo`2No`030?oo04Wo00<0ool05Ol001_o00<0ool0WOl00`3o
o`1:o`030?oo01Go000Ko`80W_l00`3oo`1;o`030?oo01Co000Ko`030?oo09co00<0ool0COl00`3o
o`0Co`006ol00`3oo`2Ko`030?oo04ko00<0ool04ol001_o00<0ool0Vol00`3oo`1?o`030?oo01;o
000Ko`030?oo09[o00<0ool0DOl00`3oo`0Ao`002ol00`3oo`02o`030?oo00;o00<0ool00ol00`3o
o`2Jo`030?oo05;o00<0ool04?l000[o00<0o`001ol00`3o0004o`030?oo09Wo00<0ool0Dol00`3o
o`0@o`001Ol300;o00<0o`002Ol00`3oo`02o`030?oo09So00<0ool0EOl00`3oo`0?o`002_l00`3o
0007o`801Ol209Wo00<0ool0E_l00`3oo`0>o`002_l00`3o0007o`030?oo00Co00<0ool0Uol00`3o
o`1Go`030?oo00ko000;o`030?oo00Ko0`04o`030?oo09Oo00<0ool0F?l00`3oo`0=o`006ol00`3o
o`2Fo`030?oo05Wo00<0ool03Ol001_o00<0ool0U_l00`3oo`1Jo`030?oo00co000Ko`030?oo09Go
00<0ool0Fol00`3oo`0<o`006ol00`3oo`2Do`030?oo05go00<0ool02ol001_o00<0ool0U?l00`3o
o`1Mo`030?oo00_o000Ko`80U?l00`3oo`1Oo`030?oo00[o000Ko`030?oo09?o00<0ool0H?l00`3o
o`09o`006ol00`3oo`2Bo`030?oo067o00<0ool02Ol001_o00<0ool0TOl00`3oo`1So`030?oo00So
000Ko`030?oo097o00<0ool0Hol00`3oo`08o`006ol00`3oo`2@o`030?oo06Go00<0ool01ol001_o
00<0ool0T?l00`3oo`1Uo`030?oo00Oo000Ko`030?oo08oo00<0ool0Iol00`3oo`06o`006ol2093o
00<0ool0Iol00`3oo`06o`006ol00`3oo`2>o`030?oo06Wo00<0ool01Ol001_o00<0ool0SOl00`3o
o`1bo`006ol00`3oo`2=o`030?oo07;o000Ko`030?oo08co00<0ool0Lol001_o00<0ool0S?l00`3o
o`1co`006ol00`3oo`2;o`030?oo07Co000Ko`80Rol00`3oo`1eo`006ol00`3oo`2:o`030?oo07Go
000Ko`030?oo08Wo00<0ool0M_l001_o00<0ool0ROl00`3oo`1fo`006ol00`3oo`28o`030?oo07Oo
000Ko`030?oo02Go1@0Vo`<09ol200co00<0ool06_l302Oo00<0ool09ol200Oo000Ko`030?oo02Oo
00<0ool09_l00`3oo`0Yo`030?oo00So00<0ool07?l00`3oo`0Uo`030?l002So00<0o`001_l001_o
00<0ool09ol00`3oo`0Wo`030?oo02Oo00<0ool02?l00`3oo`0Ko`@0:?l00`3oo`0Vo`030?l000Ko
000Ko`80:?l00`3oo`0Wo`030?oo02So00<0ool01ol00`3oo`0Ko`030?l002Oo0P0Yo`801ol001_o
00<0ool09ol00`3oo`0Vo`030?l002Oo00<0o`002?l00`3oo`0Mo`809ol00`3oo`0Xo`030?oo00Ko
000Ko`030?oo02Ko0P0Yo`030?oo02Oo00<0ool01ol00`3oo`0No`030?oo02Go0`0Yo`801_l001_o
00<0ool0Q?l00`3oo`1ko`006ol00`3oo`24o`030?oo07_o000Ko`030?oo08?o00<0ool0O?l001_o
00<0ool0Pol00`3oo`1lo`006ol00`3oo`22o`030?oo07go000Dool03@0001_o0P06o`030?oo00Ko
00<0ool01Ol00`3oo`06o`030?oo00Go00<0ool01Ol00`3oo`06o`030?oo00Go00<0ool01_l00`3o
o`05o`030?oo00Ko00<0ool01Ol00`3oo`06o`030?oo00Go00<0ool01Ol00`3oo`03o`040?oo00Oo
00<0ool01_l00`3oo`05o`030?oo00Ko00<0ool01Ol00`3oo`06o`030?oo00Go00<0ool01Ol00`3o
o`06o`030?oo00Go00<0ool01_l00`3oo`05o`030?oo00Ko00<0ool01Ol00`3oo`05o`006ol202So
00<0ool09ol00`3oo`0Wo`030?oo00;o00<0ool08ol00`3oo`0Wo`030?oo02Oo00<0ool01Ol001_o
00<0o`00P?l00`3oo`1oo`006ol00`3o001oo`030?oo083o000Ko`040?oo07ko00<0ool0P?l001_o
00@0ool0OOl00`3oo`21o`006ol01@3oool007co00<0ool0POl001_o0P02o`030?oo07Wo00<0ool0
P_l001_o00<0ool00_l00`3oo`1ho`030?oo08;o000Ko`030?oo00;o00<0ool0Mol00`3oo`23o`00
6ol00`3oo`03o`030?oo07Go00<0ool0Q?l001_o00<0ool00ol00`3oo`1eo`030?oo08Co000Ko`03
0?oo00Co00<0ool0Lol00`3oo`25o`006ol00`3oo`04o`030?oo07?o00<0ool0QOl001_o00<0ool0
1Ol00`3oo`1ao`030?oo08Ko000Ko`801_l00`3oo`1ao`030?oo08Ko000Ko`030?oo00Ko00<0ool0
Kol00`3oo`27o`006ol00`3oo`06o`030?oo06oo00<0ool0Qol001_o00<0ool01ol00`3oo`1]o`03
0?oo08So000Ko`030?oo00So00<0ool0K?l00`3oo`28o`006ol00`3oo`08o`030?oo06_o00<0ool0
ROl001_o00<0ool02Ol00`3oo`1Zo`030?oo08Wo000Ko`030?oo00Wo00<0ool0JOl00`3oo`2:o`00
6ol200_o00<0ool0J?l00`3oo`2:o`006ol00`3oo`0:o`030?oo06Oo00<0ool0Rol001_o00<0ool0
2ol00`3oo`1Vo`030?oo08_o000Ko`030?oo00co00<0ool0I?l00`3oo`2<o`006ol00`3oo`0<o`03
0?oo06Co00<0ool0S?l001_o00<0ool03Ol00`3oo`1Ro`030?oo08go000Ko`030?oo00go00<0ool0
HOl00`3oo`2>o`006ol200oo00<0ool0H?l00`3oo`2>o`006ol00`3oo`0?o`030?oo05ko00<0ool0
Sol001_o00<0ool03ol00`3oo`1Mo`030?oo093o000Ko`030?oo013o00<0ool0G?l00`3oo`2@o`00
6ol00`3oo`0@o`030?oo05_o00<0ool0TOl001_o00<0ool04Ol00`3oo`1Io`030?oo09;o000;o`03
0?oo00;o00<0ool00_l00`3oo`03o`030?oo017o00<0ool0FOl00`3oo`2Bo`002_l00`3o0007o`03
0?l000Co00<0ool04_l00`3oo`1Go`030?oo09?o000:o`030?l000Wo00<0ool00_l201Co00<0ool0
E_l00`3oo`2Co`002_l00`3o0007o`801Ol00`3oo`0Co`030?oo05Go00<0ool0U?l000[o00<0o`00
1ol00`3oo`04o`030?oo01Co00<0ool0Dol00`3oo`2Eo`002ol00`3oo`06o`<01?l00`3oo`0Eo`03
0?oo05;o00<0ool0UOl001_o00<0ool05Ol00`3oo`1Ao`030?oo09Ko000Ko`030?oo01Ko00<0ool0
Col00`3oo`2Go`006ol00`3oo`0Go`030?oo04ko00<0ool0Uol001_o00<0ool06?l00`3oo`1<o`03
0?oo09So000Ko`806Ol00`3oo`1;o`030?oo09Wo000Ko`030?oo01Wo00<0ool0B_l00`3oo`2Io`00
6ol00`3oo`0Jo`030?oo04So00<0ool0V_l001_o00<0ool06_l00`3oo`17o`030?oo09_o000Ko`03
0?oo01_o00<0ool0AOl00`3oo`2Lo`006ol00`3oo`0Lo`030?oo04Co00<0ool0W?l001_o00<0ool0
7?l00`3oo`13o`030?oo09go000Ko`030?oo01go00<0ool0@Ol00`3oo`2No`006ol201oo00<0ool0
@?l00`3oo`2No`006ol00`3oo`0Oo`030?oo03ko00<0ool0Wol001_o00<0ool08?l00`3oo`0lo`03
0?oo0:3o000Ko`030?oo023o00<0ool0>ol00`3oo`2Qo`006ol00`3oo`0Qo`030?oo03[o00<0ool0
XOl001_o00<0ool08_l00`3oo`0ho`030?oo0:;o000Ko`030?oo02?o00<0ool0=_l00`3oo`2So`00
6ol00`3oo`0To`030?oo03Co00<0ool0Y?l001_o0P0Vo`030?oo03;o00<0ool0YOl001_o00<0ool0
9Ol00`3oo`0ao`030?oo0:Ko000Ko`030?oo02Ko00<0ool0;ol00`3oo`2Wo`006ol00`3oo`0Wo`03
0?oo02go00<0ool0Z?l001_o00<0ool0:?l00`3oo`0[o`030?oo0:Wo000Ko`030?oo02Wo00<0ool0
:Ol00`3oo`2Zo`006ol00`3oo`0Zo`030?oo02Oo00<0ool0Zol001_o0P0/o`030?oo02Go00<0ool0
[?l001_o00<0ool0;?l00`3oo`0So`030?oo0:go000Ko`030?oo02go0P0Qo`80/?l001_o00<0ool0
;ol201go0P2bo`006ol00`3oo`0ao`806_l00`3oo`2bo`006ol00`3oo`0co`030?oo01Go0P2eo`00
4ol500?o00<0ool0=?l301;o0P2go`005Ol00`3oo`03o`030?oo03Oo0`0=o`80^Ol001Go00<0ool0
0ol203_o3@2ko`005Ol00`3oo`03o`030?oo0?oo0ol001Go00<0ool00ol00`3oo`3oo`?o000Do`80
1Ol00`3oo`3oo`?o000Ko`030?oo0?oo0ol00?oo8Ol00?oo8Ol00?oo8Ol00?oo8Ol00?oo8Ol00?oo
8Ol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.647187, -1.13007, 
  0.0236837, 0.0127736}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
There is an important subtlety at work here, which you should be aware of. \
There are two things that have come back from this Plot command. An image and \
some output. The image is in fact a side effect created when the output is \
passed through a DisplayFunction before being returned.\
\>", "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.047619 0.272109 [
[ 0 0 0 0 ]
[ 1 2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 2 L
0 2 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
.18254 1.13605 m
.18254 .86395 L
s
% Start of user PostScript
0.5 4. 0.5 3. MAarrowhead1
% End of user PostScript
.18254 .59184 m
.18254 .31973 L
s
% Start of user PostScript
0.5 2. 0.5 1. MAarrowhead1
% End of user PostScript
.18254 1.68027 m
.18254 1.40816 L
s
% Start of user PostScript
0.5 6. 0.5 5. MAarrowhead1
% End of user PostScript
.34127 .72789 m
.65873 .72789 L
s
% Start of user PostScript
1. 2.5 2. 2.5 MAarrowhead1
% End of user PostScript
1 1 0 r
.02381 .04762 m
.34127 .04762 L
.34127 .31973 L
.02381 .31973 L
.02381 .04762 L
F
.02381 .59184 m
.34127 .59184 L
.34127 .86395 L
.02381 .86395 L
.02381 .59184 L
F
.02381 1.13605 m
.34127 1.13605 L
.34127 1.40816 L
.02381 1.40816 L
.02381 1.13605 L
F
.65873 .59184 m
.97619 .59184 L
.97619 .86395 L
.65873 .86395 L
.65873 .59184 L
F
.02381 1.68027 m
.34127 1.68027 L
.34127 1.95238 L
.02381 1.95238 L
.02381 1.68027 L
F
0 g
gsave
.18254 1.27211 -87 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 29.750000 moveto
 460.000000 29.750000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 29.750000 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Graphics) show
63.000000 26.000000 moveto
(Function) show
111.000000 26.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.18254 .72789 -87 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 29.750000 moveto
 460.000000 29.750000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 29.750000 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Display) show
63.000000 26.000000 moveto
(Function) show
111.000000 26.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.81746 .72789 -78 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Image) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.18254 .18367 -96 -16.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 29.750000 moveto
 460.000000 29.750000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 29.750000 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Output) show
69.000000 26.000000 moveto
(Expression) show
129.000000 26.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.18254 1.81633 -78 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Input) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{157, 314},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002M0001>Q000`40O003h00OWGoo002MOol009eo
o`00WGoo002MOol009eoo`00WGoo002MOol009eoo`000goo<WoPJ7oo0003OolbOn1XOol000=ooc9o
h6Qoo`000goo<WoPJ7oo0003OolbOn1XOol000=ooc9oh6Qoo`000goo<WoPJ7oo0003OolbOn1XOol0
00=ooc9oh6Qoo`000goo<WoPJ7oo0003OolbOn1XOol000=oo`Qoh0<002Moh6Qoo`000goo2GoP00<0
07oPOn009WoPJ7oo00000goo0000000300001WoP001oh7oP001oh0<0009oh0<000=oh080009oh080
00=oh08000=oh0<000=oh0800003On000000009oh003001oh7oP06Qoo`000Woo00@007oPOn00009o
h080009oh004001oh7oP0002On001@00On1oh7oP00001WoP00<007oPOn000WoP00D007oPOn1oh000
00=oh006001oh7oP001oh0000WoP00<007oPOn00J7oo0002Ool00`00On1oh003On020002On001000
On1oh0000WoP00@007oPOn1oh0<000=oh003001oh7oP009oh003001oh7oP009oh005001oh7oPOn00
0002On000`00On000002On000`00On1oh01XOol0009oo`8000=oh003001oh7oP00D0009oh0@00004
On0000000003On020003On020002On020004On0200000goP000000020003On1XOol0009oo`04001o
h7oP000_On1XOol00003Ool0000000<0021oh003001oh7oP00aoh6Qoo`000goo<WoPJ7oo0003Oolb
On1XOol000=ooc9oh6Qoo`000goo<WoPJ7oo0003OolbOn1XOol000=oo`eoh0<0029oh6Qoo`000goo
3WoP00<007oPOn008GoPJ7oo0003Ool20003On030002On020002On030003On030002On02000GOn1X
Ool0009oo`06001oh7oP001oh0000WoP00<007oP00000WoP00<007oP00000WoP00<007oP00000WoP
00<007oP00000WoP00<007oPOn0057oPJ7oo0002Ool01P00On1oh000On00009oh003001oh00000Ao
h006001oh7oP001oh0000WoP00<007oP00006GoPJ7oo0002Ool00`00On1oh00300000goP00000004
00000goP00000002000017oP000007oP1P005goPJ7oo0002Ool01000On1oh0001WoP00<007oPOn00
37oP00<007oPOn005goPJ7oo0003Ool2000`On1XOol000=ooc9oh6Qoo`000goo<WoPJ7oo0003Oolb
On1XOol000=ooc9oh6Qoo`000goo<WoPJ7oo0003OolbOn1XOol000=ooc9oh6Qoo`000goo<WoPJ7oo
0003OolbOn1XOol000=ooc9oh6Qoo`000goo<WoPJ7oo000LOol00`00Oomoo`1nOol001]oo`<007mo
o`006goo0`00Ogoo000KOol3001oOol001]oo`<007moo`006Woo1@00OWoo000JOol5001nOol001Yo
o`D007ioo`0077oo00<007ooOol0OWoo000LOol00`00Oomoo`1nOol001aoo`03001oogoo07ioo`00
77oo00<007ooOol0OWoo000LOol00`00Oomoo`1nOol001aoo`03001oogoo07ioo`0077oo00<007oo
Ool0OWoo000LOol00`00Oomoo`1nOol001aoo`03001oogoo07ioo`0077oo00<007ooOol0OWoo000L
Ool00`00Oomoo`1nOol001aoo`03001oogoo07ioo`0077oo00<007ooOol0OWoo000LOol00`00Oomo
o`1nOol001aoo`03001oogoo07ioo`0077oo00<007ooOol0OWoo000LOol00`00Oomoo`1nOol001ao
o`03001oogoo07ioo`0077oo00<007ooOol0OWoo000LOol00`00Oomoo`1nOol001aoo`03001oogoo
07ioo`0077oo00<007ooOol0OWoo000LOol00`00Oomoo`1nOol001aoo`03001oogoo07ioo`0077oo
00<007ooOol0OWoo000LOol00`00Oomoo`1nOol001aoo`03001oogoo07ioo`0077oo00<007ooOol0
OWoo000LOol00`00Oomoo`1nOol001aoo`03001oogoo07ioo`0077oo00<007ooOol0OWoo000LOol0
0`00Oomoo`1nOol001aoo`03001oogoo07ioo`0077oo00<007ooOol0OWoo0003OolbOn0aOolbOn05
Ool000=ooc9oh35ooc9oh0Eoo`000goo<WoP<Goo<WoP1Goo0003OolbOn0aOolbOn05Ool000=ooc9o
h35ooc9oh0Eoo`000goo<WoP<Goo<WoP1Goo0003OolbOn0aOolbOn05Ool000=ooc9oh35ooc9oh0Eo
o`000goo<WoP<Goo<WoP1Goo0003OolbOn0aOolbOn05Ool000=ooc9oh35ooc9oh0Eoo`000goo<WoP
<Goo<WoP1Goo0003Ool017oP0000000017oP1@000WoP00<007oP00000P000goP0P000WoP0`000goP
0P0000=oh00000000WoP00<007oPOn001goP<Goo<WoP1Goo0003Ool2On000`00On1oh002On001P00
On1oh000On00009oh003001oh00000Aoh004001oh7oP0002On001@00On1oh7oP00000WoP00<007oP
00000WoP00<007oPOn001goP<Goo<WoP1Goo0003Ool2On000`00On1oh002On001P00On1oh000On00
009oh003001oh00000Aoh003001oh7oP00=oh005001oh7oPOn000002On000`00On000002On000`00
On1oh007On0aOolbOn05Ool000=oo`9oh080009oh0800003On00000000@0009oh0<00003On000000
0080009oh08000Aoh0800003On000000008000Yoh35ooc9oh0Eoo`000goo0WoP00@007oPOn00011o
h003001oh7oP01Uoh35ooc9oh0Eoo`000goo00=oh00000000`005WoP00<007oPOn004goP<Goo6goP
0P005GoP1Goo0003OolbOn0aOolMOn000`00On1oh00BOn05Ool000=ooc9oh2Uoo`8000Ioo`]oh0<0
0007On0007oP001oh000On0010000WoP0`000WoP0P0047oP1Goo0003OolbOn0YOol60002Ool<On00
2@00On1oh000On0007oP001oh0030002On001P00On1oh000On00019oh0Eoo`000goo<WoP<@0037oP
00P007oPOn0007oP001oh0000goP00@007oPOn00009oh003001oh0000080011oh0Eoo`000goo<WoP
:Goo1`0000=oogoPOn002WoP00<007oPOn000P0000=oh000On000WoP0P000goP0`0000Aoh0000000
011oh0Eoo`000goo<WoP:Goo0`001Goo37oP00<007oPOn008goP1Goo0003Ool@On03000=On02000@
On0aOol;On03000TOn05Ool000=ooa5oh003001oh7oP00eoh003001oh7oP00ioh35ooc9oh0Eoo`00
0goo00=oh00000000P000WoP0`000WoP0P000goP0`000WoP0`000WoP10000WoP00<007oPOn003WoP
<Goo<WoP1Goo0003Ool2On001000On1oh0000WoP00<007oPOn000goP00@007oPOn00009oh004001o
h7oP0003On030002On000`00On00000?On0aOolbOn05Ool000=oo`9oh004001oh7oP0002On000`00
On1oh002On001@00On1oh7oP00000WoP00@007oPOn0000Eoh006001oh7oP001oh0003goP<Goo<WoP
1Goo0003Ool2On001@00On1oh000On000P0017oP0P0000=oh00000000P000goP00<007oPOn000WoP
0P0000Aoh000001oh08000ioh35ooc9oh0Eoo`000goo0WoP00@007oPOn00015oh003001oh7oP01Qo
h35ooc9oh0Eoo`000goo00=oh00000000P000goP00<007oPOn002goP0P006WoP<Goo<WoP1Goo0003
OolbOn0aOolbOn05Ool000=ooc9oh35ooc9oh0Eoo`000goo<WoP<Goo<WoP1Goo0003OolbOn0aOolb
On05Ool000=ooc9oh35ooc9oh0Eoo`000goo<WoP<Goo<WoP1Goo0003OolbOn0aOolbOn05Ool000=o
oc9oh35ooc9oh0Eoo`000goo<WoP<Goo<WoP1Goo0003OolbOn0aOolbOn05Ool000=ooc9oh35ooc9o
h0Eoo`0077oo00<007ooOol0OWoo000KOol3001oOol001]oo`<007moo`006goo0`00Ogoo000KOol3
001oOol001Yoo`D007ioo`006Woo1@00OWoo000JOol5001nOol001aoo`03001oogoo07ioo`0077oo
00<007ooOol0OWoo000LOol00`00Oomoo`1nOol001aoo`03001oogoo07ioo`0077oo00<007ooOol0
OWoo000LOol00`00Oomoo`1nOol001aoo`03001oogoo07ioo`0077oo00<007ooOol0OWoo000LOol0
0`00Oomoo`1nOol001aoo`03001oogoo07ioo`0077oo00<007ooOol0OWoo000LOol00`00Oomoo`1n
Ool001aoo`03001oogoo07ioo`0077oo00<007ooOol0OWoo000LOol00`00Oomoo`1nOol001aoo`03
001oogoo07ioo`0077oo00<007ooOol0OWoo000LOol00`00Oomoo`1nOol001aoo`03001oogoo07io
o`0077oo00<007ooOol0OWoo000LOol00`00Oomoo`1nOol001aoo`03001oogoo07ioo`0077oo00<0
07ooOol0OWoo000LOol00`00Oomoo`1nOol001aoo`03001oogoo07ioo`0077oo00<007ooOol0OWoo
000LOol00`00Oomoo`1nOol001aoo`03001oogoo07ioo`0077oo00<007ooOol0OWoo000LOol00`00
Oomoo`1nOol001aoo`03001oogoo07ioo`0077oo00<007ooOol0OWoo000LOol00`00Oomoo`1nOol0
01aoo`03001oogoo07ioo`000goo<WoPJ7oo0003OolbOn1XOol000=ooc9oh6Qoo`000goo<WoPJ7oo
0003OolbOn1XOol000=ooc9oh6Qoo`000goo<WoPJ7oo0003OolbOn1XOol000=ooc9oh6Qoo`000goo
<WoPJ7oo0003OolbOn1XOol000=ooc9oh6Qoo`000goo00Aoh000000000Aoh0D0009oh003001oh000
008000=oh080009oh0<000=oh0800003On000000009oh003001oh7oP00Moh6Qoo`000goo0WoP00<0
07oPOn000WoP00H007oPOn0007oP0002On000`00On000004On001000On1oh0000WoP00D007oPOn1o
h000009oh003001oh000009oh003001oh7oP00Moh6Qoo`000goo0WoP00<007oPOn000WoP00H007oP
On0007oP0002On000`00On000004On000`00On1oh003On001@00On1oh7oP00000WoP00<007oP0000
0WoP00<007oPOn001goPJ7oo0003Ool2On020002On0200000goP000000040002On0300000goP0000
00020002On020004On0200000goP00000002000:On1XOol000=oo`9oh004001oh7oP000@On000`00
On1oh00IOn1XOol000=oo`03On00000000<001Ioh003001oh7oP01=oh6Qoo`000goo<WoPJ7oo0003
OolbOn1XOol000=ooc9oh6Qoo`000goo<WoPJ7oo0003OolbOn1XOol000=ooc9oh6Qoo`000goo47oP
0`007goPJ7oo0003OolAOn000`00On1oh00NOn1XOol000=oo`=oh080009oh0<0009oh0@00005On00
0000001oh00300000goP001oh0030002On030002On02000;On1XOol000=oo`9oh003001oh00000=o
h004001oh7oPOn030002On001P00On1oh000On00009oh004001oh7oP0003On000`00On1oh004On00
0`00On1oh008On1XOol000=oo`9oh004001oh0000002On000`00On1oh003On001000On1oh0000WoP
00<007oP00000WoP00@007oPOn0000=oh003001oh7oP00=oh003001oh7oP00Uoh6Qoo`000goo0WoP
00<007oPOn000WoP10000WoP0P0000=oh00000000P000WoP0`000WoP0P000goP0`000goP0P002WoP
J7oo0003Ool2On000`00On1oh00AOn000`00On1oh00IOn1XOol000=oo`9oh0<0011oh08000Eoh003
001oh7oP01=oh6Qoo`000goo<WoPJ7oo0003OolbOn1XOol000=ooc9oh6Qoo`000goo<WoPJ7oo0003
OolbOn1XOol000=ooc9oh6Qoo`000goo<WoPJ7oo0003OolbOn1XOol000=ooc9oh6Qoo`000goo<WoP
J7oo0003OolbOn1XOol001aoo`03001oogoo07ioo`006goo0`00Ogoo000KOol3001oOol001]oo`<0
07moo`006goo0`00Ogoo000JOol5001nOol001Yoo`D007ioo`0077oo00<007ooOol0OWoo000LOol0
0`00Oomoo`1nOol001aoo`03001oogoo07ioo`0077oo00<007ooOol0OWoo000LOol00`00Oomoo`1n
Ool001aoo`03001oogoo07ioo`0077oo00<007ooOol0OWoo000LOol00`00Oomoo`1nOol001aoo`03
001oogoo07ioo`0077oo00<007ooOol0OWoo000LOol00`00Oomoo`1nOol001aoo`03001oogoo07io
o`0077oo00<007ooOol0OWoo000LOol00`00Oomoo`1nOol001aoo`03001oogoo07ioo`0077oo00<0
07ooOol0OWoo000LOol00`00Oomoo`1nOol001aoo`03001oogoo07ioo`0077oo00<007ooOol0OWoo
000LOol00`00Oomoo`1nOol001aoo`03001oogoo07ioo`0077oo00<007ooOol0OWoo000LOol00`00
Oomoo`1nOol001aoo`03001oogoo07ioo`0077oo00<007ooOol0OWoo000LOol00`00Oomoo`1nOol0
01aoo`03001oogoo07ioo`0077oo00<007ooOol0OWoo000LOol00`00Oomoo`1nOol001aoo`03001o
ogoo07ioo`0077oo00<007ooOol0OWoo000LOol00`00Oomoo`1nOol001aoo`03001oogoo07ioo`00
77oo00<007ooOol0OWoo000LOol00`00Oomoo`1nOol000=ooc9oh6Qoo`000goo<WoPJ7oo0003Oolb
On1XOol000=ooc9oh6Qoo`000goo<WoPJ7oo0003OolbOn1XOol000=ooc9oh6Qoo`000goo<WoPJ7oo
0003OolbOn1XOol000=ooc9oh6Qoo`000goo<WoPJ7oo0003OolbOn1XOol000=ooc9oh6Qoo`000goo
<WoPJ7oo0003OolbOn1XOol000=ooc9oh6Qoo`000goo<WoPJ7oo0003OolDOn03000KOn1XOol000=o
oaEoh003001oh7oP01Yoh6Qoo`000goo2goP0`0000=oh00000000WoP00<007oP00000P000goP0`00
0WoP0P0047oPJ7oo0003Ool<On001@00On1oh7oP00000WoP00<007oP00000WoP00<007oP00000WoP
00<007oP00000WoP00<007oPOn003GoPJ7oo0003Ool<On001@00On1oh7oP00000WoP00<007oP0000
0WoP00<007oP00000WoP00<007oP00004WoPJ7oo0003Ool<On000`00On1oh00400000goP00000002
000017oP000007oP1P0047oPJ7oo0003Ool<On000`00On1oh00@On000`00On1oh00@On1XOol000=o
o`]oh0<002Aoh6Qoo`000goo<WoPJ7oo0003OolbOn1XOol000=ooc9oh6Qoo`000goo<WoPJ7oo0003
OolbOn1XOol000=ooc9oh6Qoo`000goo<WoPJ7oo0003OolbOn1XOol000=ooc9oh6Qoo`000goo<WoP
J7oo0003OolbOn1XOol000=ooc9oh6Qoo`000goo<WoPJ7oo0003OolbOn1XOol000=ooc9oh6Qoo`00
0goo<WoPJ7oo0003OolbOn1XOol000=ooc9oh6Qoo`00WGoo002MOol009eoo`00WGoo002MOol009eo
o`00WGoo0000\
\>"],
  ImageRangeCache->{{{0, 156}, {313, 0}} -> {-0.0750158, -0.186815, 
  0.0201925, 0.0235579}}],

Cell["\<\
One reason why it is important to know this is when we want to construct a \
graphic by combining several graphics. We do not want to display each of the \
intermediate steps.
Here is a short program to take a flat list of data, fit a straight line to \
it and then report on the a expression and the line.\
\>", "Text"],

Cell[BoxData[
    \(LineFitReport[data_List] := 
      Block[{expr, p1, p2}, \n\t\texpr = Fit[data, {1, x}, x]; \n\t\tp1 = 
          ListPlot[data, PlotStyle -> PointSize[0.05]]; \n\t\tp2 = 
          Plot[expr, {x, Min[data], Max[data]}]; \n\t\tStylePrint[
          "\<Data fits to line:\>"]; \n\t\tStylePrint[expr]; \n\t\tShow[p1, 
          p2]; ]\)], "Input"],

Cell["\<\
This produces the intended result but also several other images.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LineFitReport[{1, 2, 4, 5, 6}]\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214286 0.238095 -0.103006 0.117721 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -3 -9 ]
[.7381 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .13244 -6 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -6 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -6 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -6 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2619 .01472 m
.2619 .02097 L
s
[(2)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(3)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(4)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(5)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(3)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(4)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(5)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(6)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .03826 m
.02756 .03826 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .08535 m
.02756 .08535 L
s
.02381 .10889 m
.02756 .10889 L
s
.02381 .15598 m
.02756 .15598 L
s
.02381 .17952 m
.02756 .17952 L
s
.02381 .20307 m
.02756 .20307 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .2737 m
.02756 .2737 L
s
.02381 .29724 m
.02756 .29724 L
s
.02381 .32079 m
.02756 .32079 L
s
.02381 .34433 m
.02756 .34433 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .41497 m
.02756 .41497 L
s
.02381 .43851 m
.02756 .43851 L
s
.02381 .46205 m
.02756 .46205 L
s
.02381 .50914 m
.02756 .50914 L
s
.02381 .53269 m
.02756 .53269 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57977 m
.02756 .57977 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.02381 .01472 Mdot
.2619 .13244 Mdot
.5 .36788 Mdot
.7381 .4856 Mdot
.97619 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{201, 124.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000390000O1000`40O003h00ObGoo000iOol3000X
Ool2000ZOol3000YOol00`00Oomoo`0:Ool003Uoo`03001oogoo02Yoo`03001oogoo02Qoo`03001o
ogoo02Moo`03001oo`0000]oo`00>Woo00<007ooOol0:7oo00<007ooOol09goo1000:Woo00<007oo
Ool02Goo000jOol00`00Oomoo`0YOol00`00Oomoo`0VOol00`00Ool0000YOol2000<Ool003Uoo`03
001oo`0002Qoo`03001oo`0002Uoo`8002Uoo`03001oogoo00]oo`00>Woo00<007ooOol0:7oo00<0
07ooOol0:Goo00<007ooOol09goo0`002goo0039Ool000ioo`<00;Qoo`003Goo1@00]goo000<Ool7
002fOol000]oo`T00;Eoo`002Woo^0001goo000;Ool9000VOol00`00Oomoo`0XOol00`00Oomoo`0Y
Ool00`00Oomoo`0XOol00`00Oomoo`0:Ool000aoo`L00;Ioo`003Goo1@00]goo000>Ool3002hOol0
00moo`03001oogoo0;Moo`003goo00<007ooOol0]goo000?Ool00`00Oomoo`2gOol000moo`03001o
ogoo0;Moo`003goo00<007ooOol0]goo000?Ool00`00Oomoo`2gOol000moo`03001oogoo0;Moo`00
3goo00<007ooOol0]goo000?Ool00`00Oomoo`2gOol000moo`03001oogoo0;Moo`003goo00<007oo
Ool0]goo000?Ool00`00Oomoo`2gOol000moo`03001oogoo02Moo`<008eoo`003goo00<007ooOol0
9Woo1@00S7oo0008Ool30004Ool00`00Oomoo`0UOol7002;Ool000Qoo`03001oogoo00Aoo`03001o
ogoo02Aoo`T008Yoo`002Goo00<007ooOol00goo0P009Goo2@00RWoo0009Ool00`00Oomoo`03Ool0
0`00Oomoo`0TOol9002:Ool000Qoo`03001oo`0000Aoo`03001oogoo02Eoo`L008]oo`002Goo00<0
07ooOol00goo00<007ooOol09Woo1@00S7oo000?Ool00`00Oomoo`0WOol3002=Ool000moo`03001o
ogoo0;Moo`003goo00<007ooOol0]goo000?Ool00`00Oomoo`2gOol000moo`03001oogoo0;Moo`00
3goo00<007ooOol0]goo000?Ool00`00Oomoo`2gOol000moo`03001oogoo0;Moo`003goo00<007oo
Ool0]goo000?Ool00`00Oomoo`2gOol000moo`03001oogoo0;Moo`003goo00<007ooOol0]goo000?
Ool00`00Oomoo`2gOol000moo`03001oogoo0;Moo`003goo00<007ooOol0]goo000?Ool00`00Oomo
o`2gOol000Qoo`8000Eoo`03001oogoo0;Moo`002Woo00<007ooOol00Woo00<007ooOol0]goo0009
Ool00`00Oomoo`03Ool2002hOol000Yoo`03001oogoo009oo`03001oogoo0;Moo`0027oo00<007oo
000017oo00<007ooOol0]goo0009Ool00`00Oomoo`03Ool00`00Oomoo`2gOol000moo`03001oogoo
0;Moo`003goo00<007ooOol0]goo000?Ool00`00Oomoo`2gOol000moo`03001oogoo0;Moo`003goo
00<007ooOol0]goo000?Ool00`00Oomoo`2gOol000moo`03001oogoo0;Moo`003goo00<007ooOol0
]goo000?Ool00`00Oomoo`2gOol000moo`03001oogoo0;Moo`003goo00<007ooOol0]goo000?Ool0
0`00Oomoo`2gOol000moo`03001oogoo0;Moo`003goo00<007ooOol0DWoo0`00HWoo000?Ool00`00
Oomoo`1AOol5001QOol000Uoo`<000=oo`03001oogoo051oo`L0061oo`002Woo00<007ooOol00Woo
00<007ooOol0Cgoo2@00Ggoo0008Ool40003Ool2001@Ool9001OOol000Qoo`03001oo`0000Aoo`03
001oogoo04moo`T005moo`002Goo0P0017oo00<007ooOol0D7oo1`00H7oo000:Ool00`00Oomoo`02
Ool00`00Oomoo`1AOol5001QOol000moo`03001oogoo059oo`<0069oo`003goo00<007ooOol0]goo
000?Ool00`00Oomoo`2gOol000moo`03001oogoo0;Moo`003goo00<007ooOol0]goo000?Ool00`00
Oomoo`2gOol000moo`03001oogoo0;Moo`003goo00<007ooOol0]goo000?Ool00`00Oomoo`2gOol0
00moo`03001oogoo0;Moo`003goo00<007ooOol0]goo000?Ool00`00Oomoo`2gOol000moo`03001o
ogoo0;Moo`003goo00<007ooOol0]goo000?Ool00`00Oomoo`1nOol3000fOol000moo`03001oogoo
07eoo`D003Eoo`002Goo00<007ooOol00goo00<007ooOol0O7oo1`00=7oo0008Ool00`00Ool00004
Ool00`00Oomoo`1kOol9000cOol000Yoo`03001oogoo009oo`8007aoo`T003=oo`0027oo0P001Goo
00<007ooOol0Ngoo2@00<goo0008Ool00`00Oomoo`04Ool00`00Oomoo`1lOol7000dOol000Qoo`<0
00Aoo`03001oogoo07eoo`D003Eoo`003goo00<007ooOol0OWoo0`00=Woo000?Ool00`00Oomoo`2g
Ool000moo`03001oogoo0;Moo`003goo00<007ooOol0]goo000?Ool00`00Oomoo`2gOol000moo`03
001oogoo0;Moo`003goo00<007ooOol0]goo000?Ool00`00Oomoo`2gOol000moo`03001oogoo0;Mo
o`003goo00<007ooOol0]goo000?Ool00`00Oomoo`2gOol000moo`03001oogoo0;Moo`003goo00<0
07ooOol0]goo000?Ool00`00Oomoo`2gOol000moo`03001oogoo0:Uoo`<000]oo`0027oo0P001Goo
00<007ooOol0Z7oo1@002Woo0008Ool00`00Ool00004Ool00`00Oomoo`2WOol70009Ool000Qoo`03
001oo`0000Aoo`800:Moo`T000Qoo`0027oo0P001Goo00<007ooOol0YWoo2@0027oo0008Ool00`00
Oomoo`04Ool00`00Oomoo`2VOol90008Ool000Uoo`8000Aoo`03001oogoo0:Moo`L000Uoo`00^Woo
1@002Woo0000\
\>"],
  ImageRangeCache->{{{0, 200}, {123.125, 0}} -> {0.65168, 0.474625, 
  0.0230299, 0.0465787}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166667 0.190476 0.0147151 0.0784805 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .0932 -6 -4.5 ]
[.01131 .0932 0 4.5 ]
[.01131 .17168 -6 -4.5 ]
[.01131 .17168 0 4.5 ]
[.01131 .25016 -6 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .32864 -6 -4.5 ]
[.01131 .32864 0 4.5 ]
[.01131 .40712 -6 -4.5 ]
[.01131 .40712 0 4.5 ]
[.01131 .4856 -6 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .56408 -6 -4.5 ]
[.01131 .56408 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(3)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(4)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(5)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(6)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0619 .01472 m
.0619 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.1381 .01472 m
.1381 .01847 L
s
.17619 .01472 m
.17619 .01847 L
s
.25238 .01472 m
.25238 .01847 L
s
.29048 .01472 m
.29048 .01847 L
s
.32857 .01472 m
.32857 .01847 L
s
.36667 .01472 m
.36667 .01847 L
s
.44286 .01472 m
.44286 .01847 L
s
.48095 .01472 m
.48095 .01847 L
s
.51905 .01472 m
.51905 .01847 L
s
.55714 .01472 m
.55714 .01847 L
s
.63333 .01472 m
.63333 .01847 L
s
.67143 .01472 m
.67143 .01847 L
s
.70952 .01472 m
.70952 .01847 L
s
.74762 .01472 m
.74762 .01847 L
s
.82381 .01472 m
.82381 .01847 L
s
.8619 .01472 m
.8619 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.9381 .01472 m
.9381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .0932 m
.03006 .0932 L
s
[(1)] .01131 .0932 1 0 Mshowa
.02381 .17168 m
.03006 .17168 L
s
[(2)] .01131 .17168 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(3)] .01131 .25016 1 0 Mshowa
.02381 .32864 m
.03006 .32864 L
s
[(4)] .01131 .32864 1 0 Mshowa
.02381 .40712 m
.03006 .40712 L
s
[(5)] .01131 .40712 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(6)] .01131 .4856 1 0 Mshowa
.02381 .56408 m
.03006 .56408 L
s
[(7)] .01131 .56408 1 0 Mshowa
.125 Mabswid
.02381 .03041 m
.02756 .03041 L
s
.02381 .04611 m
.02756 .04611 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0775 m
.02756 .0775 L
s
.02381 .10889 m
.02756 .10889 L
s
.02381 .12459 m
.02756 .12459 L
s
.02381 .14028 m
.02756 .14028 L
s
.02381 .15598 m
.02756 .15598 L
s
.02381 .18737 m
.02756 .18737 L
s
.02381 .20307 m
.02756 .20307 L
s
.02381 .21876 m
.02756 .21876 L
s
.02381 .23446 m
.02756 .23446 L
s
.02381 .26585 m
.02756 .26585 L
s
.02381 .28155 m
.02756 .28155 L
s
.02381 .29724 m
.02756 .29724 L
s
.02381 .31294 m
.02756 .31294 L
s
.02381 .34433 m
.02756 .34433 L
s
.02381 .36003 m
.02756 .36003 L
s
.02381 .37573 m
.02756 .37573 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .42281 m
.02756 .42281 L
s
.02381 .43851 m
.02756 .43851 L
s
.02381 .45421 m
.02756 .45421 L
s
.02381 .4699 m
.02756 .4699 L
s
.02381 .50129 m
.02756 .50129 L
s
.02381 .51699 m
.02756 .51699 L
s
.02381 .53269 m
.02756 .53269 L
s
.02381 .54838 m
.02756 .54838 L
s
.02381 .57977 m
.02756 .57977 L
s
.02381 .59547 m
.02756 .59547 L
s
.02381 .61117 m
.02756 .61117 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .0932 m
.06244 .11389 L
.10458 .13646 L
.14415 .15765 L
.18221 .17804 L
.22272 .19974 L
.26171 .22062 L
.30316 .24282 L
.34309 .26421 L
.3815 .28478 L
.42237 .30667 L
.46172 .32775 L
.49955 .34802 L
.53984 .3696 L
.57861 .39036 L
.61984 .41244 L
.65954 .43371 L
.69774 .45417 L
.73838 .47594 L
.77751 .4969 L
.81909 .51917 L
.85916 .54063 L
.89771 .56128 L
.93871 .58325 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{219, 135.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003K0000Qa000`40O003h00Ofgoo000cOol3000S
Ool2000VOol3000TOol00`00Oomoo`0SOol2000;Ool003=oo`03001oogoo02Eoo`03001oogoo02Ao
o`03001oogoo029oo`03001oo`0002Aoo`03001oo`0000Yoo`00=7oo00<007ooOol08goo00<007oo
Ool08goo10009Goo00<007ooOol08Woo00<007oo00002Woo000dOol00`00Oomoo`0TOol00`00Oomo
o`0ROol00`00Ool0000TOol2000UOol2000;Ool003=oo`03001oo`0002=oo`03001oo`0002Eoo`80
02Aoo`03001oogoo02Aoo`03001oogoo00Yoo`00=7oo00<007ooOol08goo00<007ooOol09Goo00<0
07ooOol08Woo0`009Goo0P002Woo003KOol00=]oo`003Woo00<007ooOol0bWoo000>Ool00`00Oomo
o`3:Ool000ioo`03001oogoo0<Yoo`002Gooc0001Woo000>Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`09Ool000ioo`03001o
ogoo0<Yoo`003Woo00<007ooOol0bWoo000>Ool00`00Oomoo`3:Ool000ioo`03001oogoo0<Yoo`00
3Woo00<007ooOol0bWoo000>Ool00`00Oomoo`3:Ool000ioo`03001oogoo0<Yoo`003Woo00<007oo
Ool0bWoo000>Ool00`00Oomoo`3:Ool000ioo`03001oogoo0<Yoo`003Woo00<007ooOol0bWoo000>
Ool00`00Oomoo`3:Ool000Ioo`D000=oo`03001oogoo0<Yoo`0027oo00<007ooOol00goo00<007oo
Ool0bWoo0008Ool00`00Oomoo`03Ool2003;Ool000Qoo`03001oogoo00=oo`<00<Yoo`0027oo00<0
07ooOol00goo00<007ooOol00P00b7oo0007Ool20005Ool00`00Oomoo`02Ool20036Ool000ioo`03
001oogoo00Aoo`03001oogoo0<=oo`003Woo00<007ooOol01Goo0P00`goo000>Ool00`00Oomoo`07
Ool20031Ool000ioo`03001oogoo00Uoo`800;moo`003Woo00<007ooOol02goo0P00_Goo000>Ool0
0`00Oomoo`0=Ool00`00Oomoo`2jOol000ioo`03001oogoo00ioo`800;Yoo`003Woo00<007ooOol0
47oo0P00^7oo000>Ool00`00Oomoo`0BOol2002fOol000ioo`03001oogoo01Aoo`800;Aoo`001goo
0`0017oo00<007ooOol05Woo0P00/Woo0007Ool00`00Oomoo`04Ool00`00Oomoo`0HOol2002`Ool0
00Qoo`03001oogoo00=oo`8001]oo`800:ioo`0027oo00<007ooOol00goo00<007ooOol077oo0P00
[7oo0007Ool00`00Ool00004Ool00`00Oomoo`0NOol2002ZOol000Qoo`03001oogoo00=oo`03001o
ogoo021oo`800:Qoo`003Woo00<007ooOol08Woo0P00YWoo000>Ool00`00Oomoo`0TOol2002TOol0
00ioo`03001oogoo02Ioo`800:9oo`003Woo00<007ooOol0:7oo00<007ooOol0Wgoo000>Ool00`00
Oomoo`0YOol2002OOol000ioo`03001oogoo02]oo`8009eoo`003Woo00<007ooOol0;Goo00<007oo
Ool0VWoo000>Ool00`00Oomoo`0^Ool2002JOol000ioo`03001oogoo031oo`8009Qoo`003Woo00<0
07ooOol0<Woo0P00UWoo0007Ool20005Ool00`00Oomoo`0dOol2002DOol000Uoo`03001oogoo009o
o`03001oogoo03Ioo`80099oo`0027oo00<007ooOol00goo0P00>Goo00<007ooOol0Sgoo0009Ool0
0`00Oomoo`02Ool00`00Oomoo`0iOol2002?Ool000Moo`03001oo`0000Aoo`03001oogoo03]oo`80
08eoo`0027oo00<007ooOol00goo00<007ooOol0?Goo00<007ooOol0RWoo000>Ool00`00Oomoo`0n
Ool2002:Ool000ioo`03001oogoo041oo`8008Qoo`003Woo00<007ooOol0@Woo0P00QWoo000>Ool0
0`00Oomoo`14Ool30023Ool000ioo`03001oogoo04Moo`80085oo`003Woo00<007ooOol0BGoo0P00
Ogoo000>Ool00`00Oomoo`1;Ool2001mOol000ioo`03001oogoo04eoo`8007]oo`003Woo00<007oo
Ool0Cgoo0P00NGoo000>Ool00`00Oomoo`1AOol2001gOol000Qoo`<000=oo`03001oogoo05=oo`80
07Eoo`002Goo00<007ooOol00Woo00<007ooOol0EGoo0P00Lgoo0007Ool40003Ool2001HOol2001a
Ool000Moo`03001oo`0000Aoo`03001oogoo05Uoo`03001oogoo06ioo`0027oo0P0017oo00<007oo
Ool0FWoo00<007ooOol0KGoo0009Ool00`00Oomoo`02Ool00`00Oomoo`1KOol2001]Ool000ioo`03
001oogoo05eoo`03001oogoo06Yoo`003Woo00<007ooOol0GWoo0P00JWoo000>Ool00`00Oomoo`1P
Ool2001XOol000ioo`03001oogoo069oo`8006Ioo`003Woo00<007ooOol0I7oo0P00I7oo000>Ool0
0`00Oomoo`1VOol2001ROol000ioo`03001oogoo06Qoo`80061oo`003Woo00<007ooOol0JWoo0P00
GWoo000>Ool00`00Oomoo`1/Ool2001LOol000ioo`03001oogoo06ioo`8005Yoo`0027oo00<007oo
Ool00goo00<007ooOol0L7oo0P00F7oo0007Ool00`00Ool00004Ool00`00Oomoo`1bOol2001FOol0
00Uoo`03001oogoo009oo`8007Eoo`8005Aoo`001goo0P001Goo00<007ooOol0MWoo00<007ooOol0
DGoo0007Ool00`00Oomoo`04Ool00`00Oomoo`1gOol2001AOol000Moo`<000Aoo`03001oogoo07Uo
o`8004moo`003Woo00<007ooOol0Ngoo0P00CGoo000>Ool00`00Oomoo`1mOol2001;Ool000ioo`03
001oogoo07moo`8004Uoo`003Woo00<007ooOol0PGoo0P00Agoo000>Ool00`00Oomoo`23Ool20015
Ool000ioo`03001oogoo08Eoo`8004=oo`003Woo00<007ooOol0Qgoo0P00@Goo000>Ool00`00Oomo
o`29Ool00`00Oomoo`0nOol000ioo`03001oogoo08Yoo`8003ioo`003Woo00<007ooOol0S7oo0P00
?7oo0007Ool20005Ool00`00Oomoo`2>Ool00`00Oomoo`0iOol000Moo`03001oo`0000Aoo`03001o
ogoo08moo`8003Uoo`001goo00<007oo000017oo0P00TWoo0P00=goo0007Ool20005Ool00`00Oomo
o`2COol2000eOol000Moo`03001oogoo00Aoo`03001oogoo09Eoo`8003=oo`0027oo0P0017oo00<0
07ooOol0Ugoo0P00<Goo000>Ool00`00Oomoo`2IOol2000_Ool000ioo`03001oogoo09]oo`8002eo
o`003Woo00<007ooOol0WGoo0P00:goo000>Ool00`00Oomoo`2OOol2000YOol000ioo`03001oogoo
0:5oo`03001oogoo02Ioo`003Woo00<007ooOol0XWoo0P009Woo000>Ool00`00Oomoo`2TOol2000T
Ool000ioo`03001oogoo0:Ioo`03001oogoo025oo`003Woo00<007ooOol0Ygoo0P008Goo000>Ool0
0`00Oomoo`2YOol2000OOol000Qoo`03001oogoo00=oo`03001oogoo0:]oo`8001eoo`0027oo00<0
07ooOol00goo00<007ooOol0[Goo0`006Woo0008Ool00`00Oomoo`03Ool2002aOol2000HOol000Uo
o`03001oogoo009oo`03001oogoo0;9oo`8001Ioo`001goo00<007oo000017oo00<007ooOol0]7oo
0P0057oo0007Ool30004Ool00`00Oomoo`2fOol2000BOol000ioo`03001oogoo0;Qoo`80011oo`00
3Woo00<007ooOol0^Woo00<007ooOol03Goo000>Ool00`00Oomoo`2kOol00`00Oomoo`0<Ool000io
o`03001oogoo0;aoo`8000aoo`003Woo00<007ooOol0_Woo00<007ooOol02Goo000>Ool00`00Oomo
o`3:Ool000ioo`03001oogoo0<Yoo`00\
\>"],
  ImageRangeCache->{{{0, 218}, {134.25, 0}} -> {0.638674, -0.72309, 
  0.0258127, 0.0626486}}]
}, Open  ]],

Cell[BoxData[
    \("Data fits to line:"\)], "Output"],

Cell[BoxData[
    \(\(-0.299999999999997157`\) + 1.29999999999999982`\ x\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166667 0.190476 0.0147151 0.0784805 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .0932 -6 -4.5 ]
[.01131 .0932 0 4.5 ]
[.01131 .17168 -6 -4.5 ]
[.01131 .17168 0 4.5 ]
[.01131 .25016 -6 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .32864 -6 -4.5 ]
[.01131 .32864 0 4.5 ]
[.01131 .40712 -6 -4.5 ]
[.01131 .40712 0 4.5 ]
[.01131 .4856 -6 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .56408 -6 -4.5 ]
[.01131 .56408 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(3)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(4)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(5)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(6)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0619 .01472 m
.0619 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.1381 .01472 m
.1381 .01847 L
s
.17619 .01472 m
.17619 .01847 L
s
.25238 .01472 m
.25238 .01847 L
s
.29048 .01472 m
.29048 .01847 L
s
.32857 .01472 m
.32857 .01847 L
s
.36667 .01472 m
.36667 .01847 L
s
.44286 .01472 m
.44286 .01847 L
s
.48095 .01472 m
.48095 .01847 L
s
.51905 .01472 m
.51905 .01847 L
s
.55714 .01472 m
.55714 .01847 L
s
.63333 .01472 m
.63333 .01847 L
s
.67143 .01472 m
.67143 .01847 L
s
.70952 .01472 m
.70952 .01847 L
s
.74762 .01472 m
.74762 .01847 L
s
.82381 .01472 m
.82381 .01847 L
s
.8619 .01472 m
.8619 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.9381 .01472 m
.9381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .0932 m
.03006 .0932 L
s
[(1)] .01131 .0932 1 0 Mshowa
.02381 .17168 m
.03006 .17168 L
s
[(2)] .01131 .17168 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(3)] .01131 .25016 1 0 Mshowa
.02381 .32864 m
.03006 .32864 L
s
[(4)] .01131 .32864 1 0 Mshowa
.02381 .40712 m
.03006 .40712 L
s
[(5)] .01131 .40712 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(6)] .01131 .4856 1 0 Mshowa
.02381 .56408 m
.03006 .56408 L
s
[(7)] .01131 .56408 1 0 Mshowa
.125 Mabswid
.02381 .03041 m
.02756 .03041 L
s
.02381 .04611 m
.02756 .04611 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0775 m
.02756 .0775 L
s
.02381 .10889 m
.02756 .10889 L
s
.02381 .12459 m
.02756 .12459 L
s
.02381 .14028 m
.02756 .14028 L
s
.02381 .15598 m
.02756 .15598 L
s
.02381 .18737 m
.02756 .18737 L
s
.02381 .20307 m
.02756 .20307 L
s
.02381 .21876 m
.02756 .21876 L
s
.02381 .23446 m
.02756 .23446 L
s
.02381 .26585 m
.02756 .26585 L
s
.02381 .28155 m
.02756 .28155 L
s
.02381 .29724 m
.02756 .29724 L
s
.02381 .31294 m
.02756 .31294 L
s
.02381 .34433 m
.02756 .34433 L
s
.02381 .36003 m
.02756 .36003 L
s
.02381 .37573 m
.02756 .37573 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .42281 m
.02756 .42281 L
s
.02381 .43851 m
.02756 .43851 L
s
.02381 .45421 m
.02756 .45421 L
s
.02381 .4699 m
.02756 .4699 L
s
.02381 .50129 m
.02756 .50129 L
s
.02381 .51699 m
.02756 .51699 L
s
.02381 .53269 m
.02756 .53269 L
s
.02381 .54838 m
.02756 .54838 L
s
.02381 .57977 m
.02756 .57977 L
s
.02381 .59547 m
.02756 .59547 L
s
.02381 .61117 m
.02756 .61117 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.02381 .0932 Mdot
.21429 .17168 Mdot
.40476 .32864 Mdot
.59524 .40712 Mdot
.78571 .4856 Mdot
.5 Mabswid
.02381 .0932 m
.06244 .11389 L
.10458 .13646 L
.14415 .15765 L
.18221 .17804 L
.22272 .19974 L
.26171 .22062 L
.30316 .24282 L
.34309 .26421 L
.3815 .28478 L
.42237 .30667 L
.46172 .32775 L
.49955 .34802 L
.53984 .3696 L
.57861 .39036 L
.61984 .41244 L
.65954 .43371 L
.69774 .45417 L
.73838 .47594 L
.77751 .4969 L
.81909 .51917 L
.85916 .54063 L
.89771 .56128 L
.93871 .58325 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{208, 128.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003@0000P1000`40O003h00Od7oo000`Ool3000R
Ool2000TOol3000QOol00`00Oomoo`0QOol2000;Ool0031oo`03001oogoo02Aoo`03001oogoo029o
o`03001oogoo01moo`03001oo`00029oo`03001oo`0000Yoo`00<Goo00<007ooOol08Woo00<007oo
Ool08Goo10008Woo00<007ooOol087oo00<007oo00002Woo000aOol00`00Oomoo`0SOol00`00Oomo
o`0POol00`00Ool0000QOol2000SOol2000;Ool0031oo`03001oo`00029oo`03001oo`0002=oo`80
025oo`03001oogoo029oo`03001oogoo00Yoo`00<Goo00<007ooOol08Woo00<007ooOol08goo00<0
07ooOol07goo0`008goo0P002Woo003@Ool00=1oo`003Goo00<007ooOol0`7oo000=Ool00`00Oomo
o`30Ool000Uool4000Ioo`003Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<0
07ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<0
07ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<0
07ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<0
07ooOol017oo00<007ooOol01Goo00<007ooOol027oo000=Ool00`00Oomoo`0ROol00`00Oomoo`0R
Ool00`00Oomoo`0QOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`08Ool000eoo`800<5o
o`003Goo00<007ooOol0`7oo000=Ool00`00Oomoo`30Ool000eoo`800<5oo`003Goo00<007ooOol0
`7oo000=Ool00`00Oomoo`30Ool000eoo`800<5oo`003Goo00<007ooOol0`7oo000=Ool00`00Oomo
o`30Ool000aoo`<00<5oo`002goo1@00`7oo0006Ool;002oOol000Qoo`X00;ioo`0027oo2P00_Woo
0008Ool:002nOol000Qoo`03001oo`0000T00;aoo`001goo0P000Woo1@0017oo0P00^Woo000<Ool3
0007Ool2002hOol000eoo`03001oogoo00Qoo`03001oogoo0;Eoo`003Goo0P002Woo0P00]Goo000=
Ool00`00Oomoo`0;Ool2002cOol000eoo`03001oogoo00eoo`03001oogoo0;1oo`003Goo0P003goo
0P00/7oo000=Ool00`00Oomoo`0@Ool2002^Ool000eoo`03001oogoo019oo`8000eoo`<009aoo`00
3Goo0P005Goo00<007ooOol02Goo1@00Vgoo0007Ool30003Ool00`00Oomoo`0EOol20008Ool7002J
Ool000Moo`03001oogoo00=oo`03001oogoo01Moo`8000Eoo`T009Uoo`0027oo00<007ooOol00Woo
0P006Woo0P000goo2@00VGoo0008Ool00`00Oomoo`02Ool00`00Oomoo`0KOol200000goo00000007
002IOol000Moo`03001oo`0000=oo`03001oogoo01eoo`T009Yoo`0027oo00<007ooOol00Woo0P00
87oo1P00Vgoo000=Ool00`00Oomoo`0QOol3002LOol000eoo`03001oogoo02=oo`8009]oo`003Goo
0P009Woo0P00VGoo000=Ool00`00Oomoo`0WOol2002GOol000eoo`03001oogoo02Uoo`8009Eoo`00
3Goo0P00;7oo00<007ooOol0TWoo000=Ool00`00Oomoo`0/Ool2002BOol000eoo`03001oogoo02io
o`80091oo`003Goo0P00<Goo0P00SWoo0007Ool20004Ool00`00Oomoo`0bOol2002<Ool000Uoo`05
001oogooOol0000fOol2002:Ool000Qoo`03001oogoo009oo`8003Moo`8008Qoo`002Goo00D007oo
Oomoo`0003Yoo`8008Ioo`001goo00<007oo00000goo00<007ooOol0>Woo0P00Q7oo0008Ool00`00
Oomoo`02Ool2000mOol20022Ool000eoo`03001oogoo03ioo`80081oo`003Goo00<007ooOol0@7oo
0P00OWoo000=Ool20013Ool00`00Oomoo`1kOol000eoo`03001oogoo04=oo`8007]oo`003Goo00<0
07ooOol0AGoo00<007ooOol0N7oo000=Ool20017Ool2001hOol000eoo`03001oogoo04Qoo`8007Io
o`003Goo00<007ooOol0AGoo0`000Woo00<007ooOol0Lgoo000=Ool20015Ool50002Ool2001cOol0
00Qoo`<0009oo`03001oogoo04=oo`L000=oo`80075oo`002Goo00D007ooOomoo`0004Aoo`T000Ao
o`8006moo`001goo10000Woo0P00@goo2@001Woo0P00KGoo0007Ool00`00Ool00003Ool00`00Oomo
o`12Ool90008Ool2001[Ool000Qoo`8000=oo`03001oogoo04=oo`L000]oo`8006Uoo`002Goo00@0
07ooOomoo`8004Eoo`D000ioo`8006Moo`003Goo00<007ooOol0AGoo0`004Goo00<007ooOol0I7oo
000=Ool00`00Oomoo`1JOol2001TOol000eoo`8005eoo`80069oo`003Goo00<007ooOol0GWoo0P00
H7oo000=Ool00`00Oomoo`1POol2001NOol000eoo`8006=oo`8005aoo`003Goo00<007ooOol0I7oo
0P00FWoo000=Ool00`00Oomoo`1VOol20002Ool3001COol000eoo`8006Uoo`H0059oo`0027oo00<0
07ooOol00Woo00<007ooOol0J7oo1`00DGoo0007Ool00`00Ool00003Ool00`00Oomoo`1WOol9001@
Ool000Uoo`04001oogooOol2001XOol9001@Ool000Moo`8000Aoo`03001oogoo06Moo`X004moo`00
1goo00<007ooOol00goo00<007ooOol0J7oo1`000Woo0P00CGoo0007Ool30003Ool2001ZOol50005
Ool2001;Ool000eoo`03001oogoo06Yoo`<000Qoo`8004Uoo`003Goo00<007ooOol0Mgoo0P00Agoo
000=Ool2001jOol20015Ool000eoo`03001oogoo07]oo`8004=oo`003Goo00<007ooOol0OGoo0P00
@Goo000=Ool20020Ool00`00Oomoo`0nOol000eoo`03001oogoo081oo`8003ioo`003Goo00<007oo
Ool0PWoo0P002goo0`00;Woo000=Ool20025Ool20008Ool5000]Ool000Moo`8000Aoo`03001oogoo
08Ioo`8000Eoo`L002aoo`001goo00<007oo00000goo00<007ooOol0R7oo0P000Woo2@00:goo0007
Ool00`00Ool00003Ool2002;Ool;000[Ool000Moo`8000Aoo`03001oogoo08aoo`T002]oo`001goo
00<007ooOol00goo00<007ooOol0SGoo1`00;7oo0008Ool20003Ool2002?Ool5000]Ool000eoo`03
001oogoo08moo`@002eoo`003Goo00<007ooOol0Tgoo0P00:goo000=Ool2002FOol2000YOol000eo
o`03001oogoo09Moo`8002Moo`003Goo00<007ooOol0VGoo00<007ooOol097oo000=Ool2002KOol2
000TOol000eoo`03001oogoo09aoo`80029oo`003Goo00<007ooOol0WWoo00<007ooOol07goo000=
Ool2002POol2000OOol000Qoo`03001oogoo009oo`03001oogoo0:5oo`8001eoo`0027oo00<007oo
Ool00Woo00<007ooOol0Xgoo0P006goo0008Ool00`00Oomoo`02Ool2002VOol00`00Oomoo`0HOol0
00Uoo`05001oogooOol0002XOol2000HOol000Moo`03001oo`0000=oo`03001oogoo0:Qoo`8001Io
o`001goo0`000goo0P00Zgoo0P0057oo000=Ool00`00Oomoo`2/Ool2000BOol000eoo`03001oogoo
0:ioo`80011oo`003Goo0P00/Goo0P003Woo000=Ool00`00Oomoo`2bOol2000<Ool000eoo`03001o
ogoo0;Aoo`8000Yoo`003Goo0P00`Goo000=Ool00`00Oomoo`30Ool00001\
\>"],
  ImageRangeCache->{{{0, 207}, {127.5, 0}} -> {0.624052, -0.755207, 0.027283, 
  0.0662172}}]
}, Open  ]],

Cell["\<\
This problem is overcome by using the option DisplayFunction, available in \
all graphics functions, to supply an alternative display function. We tell it \
to use Identity, as this will do nothing but still returns a result. A copy \
of the correct display function for your computer system is stored in \
$DisplayFunction. We use this when we do want to display the result.\
\>", "Text"],

Cell[BoxData[
    RowBox[{\(LineFitReport[data_List]\), ":=", 
      RowBox[{"Block", "[", 
        RowBox[{\({expr, p1, p2}\), ",", "\n", "\t\t", 
          RowBox[{\(expr = Fit[data, {1, x}, x]\), ";", "\n", "\t\t", 
            RowBox[{"p1", "=", 
              RowBox[{"ListPlot", "[", 
                RowBox[{"data", ",", \(PlotStyle -> PointSize[0.05]\), ",", 
                  StyleBox[\(DisplayFunction -> Identity\),
                    FontColor->GrayLevel[0.333333]]}], "]"}]}], ";", "\n", 
            "\t\t", 
            RowBox[{"p2", "=", 
              RowBox[{"Plot", "[", 
                RowBox[{"expr", ",", \({x, Min[data], Max[data]}\), ",", 
                  StyleBox[\(DisplayFunction -> Identity\),
                    FontColor->GrayLevel[0.333333]]}], "]"}]}], ";", "\n", 
            "\t\t", \(StylePrint["\<Data fits to line:\>"]\), ";", "\n", 
            "\t\t", \(StylePrint[expr]\), ";", "\n", "\t\t", 
            RowBox[{"Show", "[", 
              RowBox[{"p1", ",", "p2", ",", 
                StyleBox[\(DisplayFunction -> $DisplayFunction\),
                  FontColor->GrayLevel[0.333333]]}], "]"}], ";"}]}], "]"}]}]
      ], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LineFitReport[{1, 2, 4, 5, 6}]\)], "Input"],

Cell[BoxData[
    \("Data fits to line:"\)], "Output"],

Cell[BoxData[
    \(\(-0.299999999999997157`\) + 1.29999999999999982`\ x\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166667 0.190476 0.0147151 0.0784805 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .0932 -6 -4.5 ]
[.01131 .0932 0 4.5 ]
[.01131 .17168 -6 -4.5 ]
[.01131 .17168 0 4.5 ]
[.01131 .25016 -6 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .32864 -6 -4.5 ]
[.01131 .32864 0 4.5 ]
[.01131 .40712 -6 -4.5 ]
[.01131 .40712 0 4.5 ]
[.01131 .4856 -6 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .56408 -6 -4.5 ]
[.01131 .56408 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(3)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(4)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(5)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(6)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0619 .01472 m
.0619 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.1381 .01472 m
.1381 .01847 L
s
.17619 .01472 m
.17619 .01847 L
s
.25238 .01472 m
.25238 .01847 L
s
.29048 .01472 m
.29048 .01847 L
s
.32857 .01472 m
.32857 .01847 L
s
.36667 .01472 m
.36667 .01847 L
s
.44286 .01472 m
.44286 .01847 L
s
.48095 .01472 m
.48095 .01847 L
s
.51905 .01472 m
.51905 .01847 L
s
.55714 .01472 m
.55714 .01847 L
s
.63333 .01472 m
.63333 .01847 L
s
.67143 .01472 m
.67143 .01847 L
s
.70952 .01472 m
.70952 .01847 L
s
.74762 .01472 m
.74762 .01847 L
s
.82381 .01472 m
.82381 .01847 L
s
.8619 .01472 m
.8619 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.9381 .01472 m
.9381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .0932 m
.03006 .0932 L
s
[(1)] .01131 .0932 1 0 Mshowa
.02381 .17168 m
.03006 .17168 L
s
[(2)] .01131 .17168 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(3)] .01131 .25016 1 0 Mshowa
.02381 .32864 m
.03006 .32864 L
s
[(4)] .01131 .32864 1 0 Mshowa
.02381 .40712 m
.03006 .40712 L
s
[(5)] .01131 .40712 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(6)] .01131 .4856 1 0 Mshowa
.02381 .56408 m
.03006 .56408 L
s
[(7)] .01131 .56408 1 0 Mshowa
.125 Mabswid
.02381 .03041 m
.02756 .03041 L
s
.02381 .04611 m
.02756 .04611 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0775 m
.02756 .0775 L
s
.02381 .10889 m
.02756 .10889 L
s
.02381 .12459 m
.02756 .12459 L
s
.02381 .14028 m
.02756 .14028 L
s
.02381 .15598 m
.02756 .15598 L
s
.02381 .18737 m
.02756 .18737 L
s
.02381 .20307 m
.02756 .20307 L
s
.02381 .21876 m
.02756 .21876 L
s
.02381 .23446 m
.02756 .23446 L
s
.02381 .26585 m
.02756 .26585 L
s
.02381 .28155 m
.02756 .28155 L
s
.02381 .29724 m
.02756 .29724 L
s
.02381 .31294 m
.02756 .31294 L
s
.02381 .34433 m
.02756 .34433 L
s
.02381 .36003 m
.02756 .36003 L
s
.02381 .37573 m
.02756 .37573 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .42281 m
.02756 .42281 L
s
.02381 .43851 m
.02756 .43851 L
s
.02381 .45421 m
.02756 .45421 L
s
.02381 .4699 m
.02756 .4699 L
s
.02381 .50129 m
.02756 .50129 L
s
.02381 .51699 m
.02756 .51699 L
s
.02381 .53269 m
.02756 .53269 L
s
.02381 .54838 m
.02756 .54838 L
s
.02381 .57977 m
.02756 .57977 L
s
.02381 .59547 m
.02756 .59547 L
s
.02381 .61117 m
.02756 .61117 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.02381 .0932 Mdot
.21429 .17168 Mdot
.40476 .32864 Mdot
.59524 .40712 Mdot
.78571 .4856 Mdot
.5 Mabswid
.02381 .0932 m
.06244 .11389 L
.10458 .13646 L
.14415 .15765 L
.18221 .17804 L
.22272 .19974 L
.26171 .22062 L
.30316 .24282 L
.34309 .26421 L
.3815 .28478 L
.42237 .30667 L
.46172 .32775 L
.49955 .34802 L
.53984 .3696 L
.57861 .39036 L
.61984 .41244 L
.65954 .43371 L
.69774 .45417 L
.73838 .47594 L
.77751 .4969 L
.81909 .51917 L
.85916 .54063 L
.89771 .56128 L
.93871 .58325 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{203, 125.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003;0000OA000`40O003h00Obgoo000_Ool3000Q
Ool2000SOol3000POol00`00Oomoo`0POol2000;Ool002moo`03001oogoo02=oo`03001oogoo025o
o`03001oogoo01ioo`03001oo`00025oo`03001oo`0000Yoo`00<7oo00<007ooOol08Goo00<007oo
Ool087oo10008Goo00<007ooOol07goo00<007oo00002Woo000`Ool00`00Oomoo`0ROol00`00Oomo
o`0OOol00`00Ool0000POol2000ROol2000;Ool002moo`03001oo`00025oo`03001oo`00029oo`80
021oo`03001oogoo025oo`03001oogoo00Yoo`00<7oo00<007ooOol08Goo00<007ooOol08Woo00<0
07ooOol07Woo0`008Woo0P002Woo003;Ool00<]oo`003Goo00<007ooOol0^goo000=Ool00`00Oomo
o`2kOol000Uook`000Ioo`003Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<0
07ooOol017oo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo00<0
07ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo00<0
07ooOol017oo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<0
07ooOol017oo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo00<0
07ooOol01Goo00<007ooOol017oo00<007ooOol027oo000=Ool00`00Oomoo`0QOol00`00Oomoo`0Q
Ool00`00Oomoo`0POol00`00Oomoo`0QOol00`00Oomoo`0QOol00`00Oomoo`08Ool000eoo`800;ao
o`003Goo00<007ooOol0^goo000=Ool00`00Oomoo`2kOol000eoo`800;aoo`003Goo00<007ooOol0
^goo000=Ool00`00Oomoo`2kOol000eoo`800;aoo`003Goo00<007ooOol0^goo000<Ool3002lOol0
00]oo`D00;]oo`001Woo2`00^Woo0008Ool:002iOol000Qoo`X00;Uoo`0027oo2P00^Goo0008Ool0
0`00Ool00007002iOol000Moo`80009oo`D0009oo`800;Moo`0037oo0`001Goo00<007ooOol0]7oo
000=Ool00`00Oomoo`05Ool2002dOol000eoo`8000Qoo`800;9oo`003Goo00<007ooOol02Goo0P00
/7oo000=Ool00`00Oomoo`0;Ool2002^Ool000eoo`8000ioo`800:aoo`003Goo00<007ooOol03goo
0P00ZWoo000=Ool00`00Oomoo`0AOol2000=Ool3002HOol000eoo`8001Aoo`8000Yoo`D009Moo`00
1goo0`000goo00<007ooOol05Goo0P001goo1`00UWoo0007Ool00`00Oomoo`03Ool00`00Oomoo`0G
Ool20004Ool9002EOol000Qoo`03001oogoo009oo`8001Yoo`80009oo`T009Eoo`0027oo00<007oo
Ool00Woo00<007ooOol06goo00<007oo00002000UGoo0007Ool00`00Ool00003Ool00`00Oomoo`0L
Ool9002FOol000Qoo`03001oogoo009oo`8001moo`H009Moo`003Goo00<007ooOol087oo0`00V7oo
000=Ool00`00Oomoo`0ROol00`00Oomoo`2FOol000eoo`8002Aoo`8009Ioo`003Goo00<007ooOol0
9Goo0P00U7oo000=Ool00`00Oomoo`0WOol2002BOol000eoo`8002Yoo`80091oo`003Goo00<007oo
Ool0:goo0P00SWoo000=Ool00`00Oomoo`0]Ool2002<Ool000eoo`80031oo`8008Yoo`001goo0P00
17oo00<007ooOol0<Goo0P00R7oo0009Ool01@00Oomoogoo0000=Goo0P00QWoo0008Ool00`00Oomo
o`02Ool2000fOol20024Ool000Uoo`05001oogooOol0000iOol20022Ool000Moo`03001oo`0000=o
o`03001oogoo03Uoo`03001oogoo07moo`0027oo00<007ooOol00Woo0P00>goo0P00Ogoo000=Ool0
0`00Oomoo`0lOol2001mOol000eoo`8003moo`8007]oo`003Goo00<007ooOol0@7oo00<007ooOol0
N7oo000=Ool00`00Oomoo`11Ool2001hOol000eoo`8004Aoo`8007Ioo`003Goo00<007ooOol0AGoo
0P00M7oo000=Ool00`00Oomoo`13Ool300000goo0000001bOol000eoo`8004=oo`D0009oo`80071o
o`0027oo0`000Woo00<007ooOol0@Goo1`000goo0P00KWoo0009Ool01@00Oomoogoo0000@Woo2@00
17oo0P00K7oo0007Ool40002Ool20011Ool90006Ool00`00Oomoo`1YOol000Moo`03001oo`0000=o
o`03001oogoo041oo`T000Moo`8006Uoo`0027oo0P000goo00<007ooOol0@Goo1`002Woo0P00Igoo
0009Ool01000Oomoogoo0P00@goo1@003Goo0P00IGoo000=Ool00`00Oomoo`13Ool3000@Ool00`00
Oomoo`1ROol000eoo`03001oogoo05Moo`80069oo`003Goo0P00FWoo0P00H7oo000=Ool00`00Oomo
o`1KOol2001NOol000eoo`03001oogoo05eoo`8005aoo`003Goo0P00H7oo0P00FWoo000=Ool00`00
Oomoo`1QOol2001HOol000eoo`03001oogoo06=oo`80009oo`<0055oo`003Goo0P00IWoo1P00D7oo
0008Ool00`00Oomoo`02Ool00`00Oomoo`1UOol7001?Ool000Moo`03001oo`0000=oo`03001oogoo
06Aoo`T004ioo`002Goo00@007ooOomoo`8006Eoo`T004ioo`001goo0P0017oo00<007ooOol0I7oo
2P00CGoo0007Ool00`00Oomoo`03Ool00`00Oomoo`1UOol70002Ool2001;Ool000Moo`<000=oo`80
06Moo`D000Eoo`8004Uoo`003Goo00<007ooOol0Igoo0`0027oo0P00Agoo000=Ool00`00Oomoo`1d
Ool00`00Oomoo`14Ool000eoo`8007Ioo`8004Aoo`003Goo00<007ooOol0Mgoo0P00@Woo000=Ool0
0`00Oomoo`1iOol20010Ool000eoo`8007aoo`03001oogoo03eoo`003Goo00<007ooOol0O7oo0P00
?Goo000=Ool00`00Oomoo`1nOol2000;Ool3000]Ool000eoo`80085oo`8000Qoo`D002aoo`001goo
0P0017oo00<007ooOol0PWoo0P001Goo1`00:goo0007Ool00`00Ool00003Ool00`00Oomoo`24Ool2
0002Ool9000ZOol000Moo`03001oo`0000=oo`8008Moo`/002Yoo`001goo0P0017oo00<007ooOol0
R7oo2@00:Woo0007Ool00`00Oomoo`03Ool00`00Oomoo`29Ool7000[Ool000Qoo`8000=oo`8008]o
o`D002aoo`003Goo00<007ooOol0Rgoo1000;7oo000=Ool00`00Oomoo`2?Ool2000ZOol000eoo`80
099oo`8002Qoo`003Goo00<007ooOol0Tgoo0P009Woo000=Ool00`00Oomoo`2EOol2000TOol000eo
o`8009Qoo`80029oo`003Goo00<007ooOol0VGoo0P0087oo000=Ool2002LOol2000NOol000Qoo`03
001oogoo009oo`03001oogoo09eoo`8001aoo`0027oo00<007ooOol00Woo00<007ooOol0Wgoo0P00
6Woo0008Ool00`00Oomoo`02Ool2002ROol00`00Oomoo`0GOol000Uoo`05001oogooOol0002TOol2
000GOol000Moo`03001oo`0000=oo`03001oogoo0:Aoo`8001Eoo`001goo0`000goo0P00Ygoo0P00
4goo000=Ool00`00Oomoo`2XOol2000AOol000eoo`03001oogoo0:Yoo`8000moo`003Goo0P00[Goo
0P003Goo000=Ool00`00Oomoo`2^Ool2000;Ool000eoo`03001oogoo0;1oo`03001oogoo00Qoo`00
3Goo0P00_7oo000=Ool00`00Oomoo`2kOol00001\
\>"],
  ImageRangeCache->{{{0, 202}, {124.375, 0}} -> {0.615406, -0.771349, 
  0.028022, 0.0680108}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Formatting data", "Section"],

Cell["\<\
We now have a basic mechanism for sending information back. Now we must look \
at what we are sending back to be displayed. The same data can be displayed \
in several ways. This is most simply seen in graphics where there are range \
of different plot commands which essentially allow us to present the same \
data in a different way. EG A list of values could be a PieChart or a \
BarChart etc.
A number of commands are given that allow us to format other output without \
having to take the output apart and reprocess it.\
\>", "Text"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"AccountingForm\"\>", "\<\"BaseForm\"\>", "\<\"BoxForm\"\>"},
          {"\<\"CForm\"\>", "\<\"ColonForm\"\>", "\<\"ColumnForm\"\>"},
          {"\<\"DisplayForm\"\>", "\<\"EngineeringForm\"\>", 
            "\<\"FortranForm\"\>"},
          {"\<\"FullForm\"\>", "\<\"HoldForm\"\>", "\<\"HorizontalForm\"\>"},
          {"\<\"InputForm\"\>", "\<\"MatrixForm\"\>", "\<\"NumberForm\"\>"},
          {"\<\"OutputForm\"\>", "\<\"PaddedForm\"\>", 
            "\<\"PrecedenceForm\"\>"},
          {"\<\"ScientificForm\"\>", "\<\"SequenceForm\"\>", 
            "\<\"SpaceForm\"\>"},
          {"\<\"StandardForm\"\>", "\<\"StringForm\"\>", 
            "\<\"StyleForm\"\>"},
          {"\<\"TableForm\"\>", "\<\"TeXForm\"\>", "\<\"TextForm\"\>"},
          {"\<\"TraditionalForm\"\>", "\<\"TreeForm\"\>", "\<\"\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"],

Cell["Lets look at just a few of these:", "Text"],

Cell[CellGroupData[{

Cell["Formatting Numbers", "Subsubsection"],

Cell["There are several conventions for presenting numbers.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(2^30\)], "Input"],

Cell[BoxData[
    \(1073741824\)], "Output"]
}, Open  ]],

Cell["\<\
We can, for example break up long blocks of digits using commas\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NumberForm[2^30, DigitBlock -> 3]\)], "Input"],

Cell[BoxData[
    TagBox[
      InterpretationBox["\<\"1,073,741,824\"\>",
        1073741824,
        Editable->False],
      (NumberForm[ #, DigitBlock -> 3]&)]], "Output"]
}, Open  ]],

Cell["Or any other set of characters", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NumberForm[2^30, DigitBlock -> 3, NumberSeparator -> "\< \>"]\)], 
  "Input"],

Cell[BoxData[
    TagBox[
      InterpretationBox["\<\"1 073 741 824\"\>",
        1073741824,
        Editable->False],
      (NumberForm[ #, DigitBlock -> 3, NumberSeparator -> " "]&)]], "Output"]
}, Open  ]],

Cell["\<\
We can change the way that we show negative and positive numbers, and decimal \
points. For example, my British bank statements use OD for Over Drawn to \
denote negative numbers\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NumberForm[\(-2200.06\), NumberSigns -> {"\< OD \>", "\<\[Bullet]\>"}, 
      NumberPoint -> "\< \[LongDash] \>"]\)], "Input"],

Cell[BoxData[
    TagBox[
      InterpretationBox["\<\" OD 2200 \[LongDash] 06\"\>",
        -2200.0599999999999,
        AutoDelete->True],
      (NumberForm[ #, NumberSigns -> {" OD ", "\[Bullet]"}, NumberPoint -> 
        " \[LongDash] "]&)]], "Output"]
}, Open  ]],

Cell["\<\
Several commands are given that attempt to follow particular conventions so \
that you do not have to specify the details in NumberForm. For example, \
EngineeringForm uses exponents which are always a multiple of 3.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(EngineeringForm[2. ^24]\)], "Input"],

Cell[BoxData[
    TagBox[
      InterpretationBox[\("16.7772"\[Times]10\^"6"\),
        16777216.0,
        AutoDelete->True],
      EngineeringForm]], "Output"]
}, Open  ]],

Cell["Lets look at some tabulated data now.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(data = Table[Random[], {6}, {6}]\)], "Input"],

Cell[BoxData[
    \({{0.657072616504098228`, 0.919532525032820657`, 0.997276404603302246`, 
        0.701741215145127839`, 0.0802637049896933696`, 
        0.628489472222761236`}, {0.171890597362486996`, 0.40854751054237095`, 
        0.202640209253586078`, 0.589967316937958585`, 0.486693825278189962`, 
        0.250308503950633021`}, {0.808431430763482516`, 
        0.425415398610420147`, 0.0885199107283113839`, 0.119716953488804689`, 
        0.182992191351789443`, 0.520239878594931237`}, {
        0.566505409883691335`, 0.490941017303135929`, 0.317498313149661548`, 
        0.382670874623024648`, 0.934134319825592029`, 
        0.949178602719501185`}, {0.66042569664556332`, 0.463138349590203901`, 
        0.936857915222289783`, 0.247437387574373213`, 0.580161991655869879`, 
        0.834648877367442665`}, {0.764967317859802786`, 
        0.838889877032002218`, 0.377521782402283845`, 0.244681560429484168`, 
        0.278273492581612824`, 0.588581373081369108`}}\)], "Output"]
}, Open  ]],

Cell["We might want a neat matrix out of this data", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm[data]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0.657072616504098228`", "0.919532525032820657`", 
              "0.997276404603302246`", "0.701741215145127839`", 
              "0.0802637049896933696`", "0.628489472222761236`"},
            {"0.171890597362486996`", "0.40854751054237095`", 
              "0.202640209253586078`", "0.589967316937958585`", 
              "0.486693825278189962`", "0.250308503950633021`"},
            {"0.808431430763482516`", "0.425415398610420147`", 
              "0.0885199107283113839`", "0.119716953488804689`", 
              "0.182992191351789443`", "0.520239878594931237`"},
            {"0.566505409883691335`", "0.490941017303135929`", 
              "0.317498313149661548`", "0.382670874623024648`", 
              "0.934134319825592029`", "0.949178602719501185`"},
            {"0.66042569664556332`", "0.463138349590203901`", 
              "0.936857915222289783`", "0.247437387574373213`", 
              "0.580161991655869879`", "0.834648877367442665`"},
            {"0.764967317859802786`", "0.838889877032002218`", 
              "0.377521782402283845`", "0.244681560429484168`", 
              "0.278273492581612824`", "0.588581373081369108`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
A little large, so lets specify that the digits should only be shown to two \
decimal places. We can do this by combining MatrixForm with NumberForm\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NumberForm[MatrixForm[data], 2]\)], "Input"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", GridBox[{
              {
                InterpretationBox["\<\"0.66\"\>",
                  .65707261650409821,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.92\"\>",
                  .91953252503282068,
                  AutoDelete->True], 
                InterpretationBox["\<\"1.\"\>",
                  .99727640460330225,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.7\"\>",
                  .70174121514512788,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.08\"\>",
                  .08026370498969336,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.63\"\>",
                  .62848947222276119,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"0.17\"\>",
                  .17189059736248699,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.41\"\>",
                  .40854751054237098,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.2\"\>",
                  .20264020925358608,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.59\"\>",
                  .58996731693795856,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.49\"\>",
                  .48669382527818994,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.25\"\>",
                  .25030850395063303,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"0.81\"\>",
                  .80843143076348245,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.43\"\>",
                  .4254153986104201,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.089\"\>",
                  .088519910728311391,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.12\"\>",
                  .11971695348880468,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.18\"\>",
                  .18299219135178943,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.52\"\>",
                  .52023987859493126,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"0.57\"\>",
                  .56650540988369136,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.49\"\>",
                  .49094101730313588,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.32\"\>",
                  .31749831314966154,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.38\"\>",
                  .38267087462302463,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.93\"\>",
                  .93413431982559203,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.95\"\>",
                  .94917860271950116,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"0.66\"\>",
                  .66042569664556328,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.46\"\>",
                  .46313834959020395,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.94\"\>",
                  .93685791522228978,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.25\"\>",
                  .24743738757437322,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.58\"\>",
                  .5801619916558699,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.83\"\>",
                  .83464887736744275,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"0.76\"\>",
                  .76496731785980276,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.84\"\>",
                  .83888987703200224,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.38\"\>",
                  .37752178240228385,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.24\"\>",
                  .24468156042948416,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.28\"\>",
                  .27827349258161282,
                  AutoDelete->True], 
                InterpretationBox["\<\"0.59\"\>",
                  .58858137308136915,
                  AutoDelete->True]}
              }], ")"}],
        (MatrixForm[ #]&)],
      (NumberForm[ #, 2]&)]], "Output"]
}, Open  ]],

Cell["\<\
TableForm is similar but allows us to specify headings and some other \
details.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[data, TableSpacing -> 1, 
      TableHeadings -> {{"\<A\>", "\<B\>", "\<C\>", "\<D\>", "\<E\>", 
            "\<F\>"}, {"\<One\>", "\<Two\>", "\<Three\>", "\<Four\>", 
            "\<Five\>", "\<Six\>"}}]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"One\"\>", "\<\"Two\"\>", "\<\"Three\"\>", 
            "\<\"Four\"\>", "\<\"Five\"\>", "\<\"Six\"\>"},
          {"\<\"A\"\>", "0.657072616504098228`", "0.919532525032820657`", 
            "0.997276404603302246`", "0.701741215145127839`", 
            "0.0802637049896933696`", "0.628489472222761236`"},
          {"\<\"B\"\>", "0.171890597362486996`", "0.40854751054237095`", 
            "0.202640209253586078`", "0.589967316937958585`", 
            "0.486693825278189962`", "0.250308503950633021`"},
          {"\<\"C\"\>", "0.808431430763482516`", "0.425415398610420147`", 
            "0.0885199107283113839`", "0.119716953488804689`", 
            "0.182992191351789443`", "0.520239878594931237`"},
          {"\<\"D\"\>", "0.566505409883691335`", "0.490941017303135929`", 
            "0.317498313149661548`", "0.382670874623024648`", 
            "0.934134319825592029`", "0.949178602719501185`"},
          {"\<\"E\"\>", "0.66042569664556332`", "0.463138349590203901`", 
            "0.936857915222289783`", "0.247437387574373213`", 
            "0.580161991655869879`", "0.834648877367442665`"},
          {"\<\"F\"\>", "0.764967317859802786`", "0.838889877032002218`", 
            "0.377521782402283845`", "0.244681560429484168`", 
            "0.278273492581612824`", "0.588581373081369108`"}
          },
        RowSpacings->1,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> 1, TableHeadings -> {{"A", "B", "C", 
        "D", "E", "F"}, {"One", "Two", "Three", "Four", "Five", "Six"}}]&)]], 
  "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Formatting Expressions", "Subsubsection"],

Cell["Here is an expression", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(expr = Integrate[1/\((1 + x^3)\), x]\)], "Input"],

Cell[BoxData[
    \(ArcTan[\(\(-1\) + 2\ x\)\/\@3]\/\@3 + 1\/3\ Log[1 + x] - 
      1\/6\ Log[1 - x + x\^2]\)], "Output"]
}, Open  ]],

Cell["\<\
Just as with numbers, there are several alternative ways to show this \
expression. Here is the same expression using the traditional textbook \
formatting rules.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm[expr]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`\(\(tan\^\(-1\)\)(\(2\ x - 1\)\/\@3)\)\/\@3 + 1\/3\ \(log(x + 1)\) - 
      1\/6\ \(log(x\^2 - x + 1)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Similarly InputForm and OutputForm are the linear text based and \
two-dimensional text based forms which were used in earlier versions of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and are now mainly useful for email or other text based communication \
with non-",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " users."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(InputForm[expr]\)], "Input"],

Cell["\<\
ArcTan[(-1 + 2*x)/Sqrt[3]]/Sqrt[3] + Log[1 + x]/3 - Log[1 - x + x^2]/6\
\>", "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(OutputForm[expr]\)], "Input"],

Cell[OutputFormData["\<\
ArcTan[(-1 + 2*x)/Sqrt[3]]/Sqrt[3] + Log[1 + x]/3 - Log[1 - x + x^2]/6\
\>", "\<\
       -1 + 2 x
ArcTan[--------]                             2
       Sqrt[3]     Log[1 + x]   Log[1 - x + x ]
---------------- + ---------- - ---------------
    Sqrt[3]            3               6\
\>"], "Output"]
}, Open  ]],

Cell["\<\
There are also formatting commands for the conventions of other computer \
languages,\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TeXForm[expr]\)], "Input"],

Cell["\<\
{\\frac{\\arctan ({\\frac{-1 + 2\\,x}{{\\sqrt{3}}}})}{{\\sqrt{3}}}} + 
  {\\frac{\\log (1 + x)}{3}} - {\\frac{\\log (1 - x + {x^2})}{6}}\
\>", "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FortranForm[expr]\)], "Input"],

Cell["\<\
        ArcTan((-1 + 2*x)/Sqrt(3))/Sqrt(3) + Log(1 + x)/3. - 
     -  Log(1 - x + x**2)/6.\
\>", "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CForm[expr]\)], "Input"],

Cell["\<\
ArcTan((-1 + 2*x)/Sqrt(3))/Sqrt(3) + Log(1 + x)/3. - 
   Log(1 - x + Power(x,2))/6.\
\>", "Output"]
}, Open  ]],

Cell["\<\
Two quite different but useful functions are Short and HoldForm. Short is an \
intelligent way of truncating long expressions to help the user see the basic \
structure it.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Short[Expand[expr\^4]]\)], "Input"],

Cell[BoxData[
    TagBox[
      \(1\/9\ ArcTan[\(\(-1\) + 2\ x\)\/\@3]\^4 + 
        \(4\ \[LeftSkeleton]1\[RightSkeleton]\ Log[1 + x]\)\/\(9\ \@3\) + 
        \[LeftSkeleton]18\[RightSkeleton] + 
        Log[\[LeftSkeleton]1\[RightSkeleton]]\^4\/1296\),
      Short]], "Output"]
}, Open  ]],

Cell["\<\
And HoldForm stops the expression from evaluating but is otherwise invisible.\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(HoldForm[2 + 2]\)], "Input"],

Cell[BoxData[
    TagBox[\(2 + 2\),
      HoldForm]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styling output", "Section"],

Cell["\<\
If we are to achieve our aim of producing reports which do not need to be \
edited manually before presentation then we need also to deal with the \
aesthetics of making the report presentable. We must produce output which is \
already attractively styled.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Setting style information", "Subsubsection"],

Cell["\<\
We can use StylePrint with front end options associated with styles. You can \
find these option names in the OptionInspector. We can use any of the options \
which can be applied to a Cell.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StylePrint["\<Hello\>", TextAlignment -> Center, FontSize -> 36, \n\t
      FontFamily -> "\<Times\>", FontWeight -> Bold, 
      Background -> RGBColor[1, 0, 0], FontColor -> RGBColor[0, 0, 1]]\)], 
  "Input"],

Cell[BoxData[
    \("Hello"\)], "Output",
  TextAlignment->Center,
  FontFamily->"Times",
  FontSize->36,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 0, 0]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["StyleSheets", "Subsubsection"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " makes it possible to create style sheets which group a set of options \
under a style name. We can change style sheets and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will automatically apply the new options associated with the style names. \
StylePrint also allows us to create cells which are tagged with particular \
style names which are defined for the notebook."
}], "Text"],

Cell[BoxData[
    \(StylePrint["\<Hello\>", "\<Title\>"]\)], "Input"],

Cell["\<\
Here is a set of common style names. The actual list available will depend \
upon the style sheet that you choose to use and can be found under the Style \
menu.\
\>", "Text"],

Cell[BoxData[
    \(\(Styles = 
      {"\<Title\>", "\<Subtitle\>", "\<Subsubtitle\>", "\<Section\>", 
        "\<Subsection\>", "\<Subsubsection\>", "\<Text\>"}; \)\)], "Input"],

Cell["\<\
Here is a short program which will show us what each of these styles looks \
like in our current style sheet.\
\>", "Text"],

Cell[BoxData[
    \(Map[StylePrint[#, #]&, Styles]\)], "Input"],

Cell["You can use built in styles and override individual settings", "Text"],

Cell[BoxData[
    \(Do[StylePrint[i, "\<Title\>", FontSize -> i], {i, 10, 40, 5}]\)], 
  "Input"],

Cell["\<\
Lets revisit our LineFitReport program and use some of these new \
capabilities.\
\>", "Text"],

Cell[BoxData[
    RowBox[{\(LineFitReport[data_List]\), ":=", 
      RowBox[{"Block", "[", 
        RowBox[{\({expr, p1, p2}\), ",", "\n", "\t\t", 
          RowBox[{
          \(expr = Fit[data, {1, x}, x]\), ";", "\n", "\t\t", 
            \(p1 = ListPlot[data, PlotStyle -> PointSize[0.05], 
                DisplayFunction -> Identity]\), ";", "\n", "\t\t", 
            \(p2 = Plot[expr, {x, Min[data], Max[data]}, 
                DisplayFunction -> Identity]\), ";", "\n", "\t\t", 
            RowBox[{"StylePrint", "[", 
              RowBox[{"\"\<Data fit report\>\"", ",", 
                StyleBox["\"\<Title\>\"",
                  FontColor->GrayLevel[0.333333]]}], "]"}], ";", 
            RowBox[{"StylePrint", "[", 
              RowBox[{"\"\<Data fits to line:\>\"", ",", 
                StyleBox["\"\<Section\>\"",
                  FontColor->GrayLevel[0.333333]]}], "]"}], ";", "\n", 
            "\t\t", 
            RowBox[{"StylePrint", "[", 
              RowBox[{\(NumberForm[expr, 2]\), ",", 
                StyleBox["\"\<Input\>\"",
                  FontColor->GrayLevel[0.333333]]}], "]"}], ";", "\n", 
            "\t\t", \(Show[p1, p2, DisplayFunction -> $DisplayFunction]\), 
            ";"}]}], "]"}]}]], "Input"],

Cell[BoxData[
    \(LineFitReport[{5, 3, 2, 1, 0}]\)], "Input"],

Cell["\<\
Now you may have noticed that everything that I have done so far has been \
returned into the notebook that I am typing into. This could cause problems: \
commands that I have typed, need to be removed, we cannot use this from a \
palette and we cannot create two separate reports simultaneously. 

Lets look at specifying exactly where our data is returned to.
\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Directing Output", "Section"],

Cell["For this we use a new command.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?NotebookWrite\)\)], "Input"],

Cell[BoxData[
    \("NotebookWrite[notebook, data] writes data into a notebook at the \
current selection, setting the current selection to be just after the data \
written. NotebookWrite[notebook, data, sel] writes data into a notebook \
setting the current selection to be as specified by sel."\)], "Print"]
}, Open  ]],

Cell["\<\
This sends data to a particular notebook. Lets make a notebook to use for \
this.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nb = NotebookCreate[]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      \(\[SkeletonIndicator]  NotebookObject  \[SkeletonIndicator]\),
      NotebookObject[ 
        FrontEndObject[ 
          LinkObject[ "wie", 1, 1]], 73],
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Incidentally, NotebookCreate[options] with any options which can be applied \
to a notebook, will create a custom notebook.eg\
\>", "Text"],

Cell[BoxData[
    \(nb = 
      NotebookCreate[Background -> GrayLevel[0.8], WindowSize -> {200, 100}]
        \)], "Input"],

Cell["\<\
This command has created a notebook in the front end and returned an object \
which acts as a pointer to that notebook.  Lets digress for a moment and look \
at this in more detail. The pointer simply gives a unique number for the \
notebook and which front-end it belongs to.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullForm[nb]\)], "Input"],

Cell[BoxData[
    TagBox[
      StyleBox[
        \(NotebookObject[FrontEndObject[LinkObject["\<wie\>", 1, 1]], 73]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True],
      FullForm]], "Output"]
}, Open  ]],

Cell["Other useful commands for specifying notebooks include", "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {"SelectedNotebook", \(The\ notebook\ in\ the\ foreground\)},
          {"EvaluationNotebook", 
            \(The\ notebook\ in\ which\ the\ current\ evaluation\ is\ taking\ 
              place\)},
          {"ButtonNotebook", 
            \(The\ notebook\ holding\ the\ button\ which\ invoked\ this\ 
              evaluation\)},
          {"NotebookCreate", 
            \(Create\ a\ new\ notebook\ and\ return\ its\ reference\)},
          {"Notebooks", \(A\ list\ of\ currently\ open\ notebooks\)}
          }], TextForm]], "Text",
  GridBoxOptions->{ColumnWidths->{10, 30},
  ColumnAlignments->{Left},
  GridFrame->True,
  RowLines->True,
  ColumnLines->True}],

Cell["\<\
This command will send the text to the new notebook as if we typed it in by \
hand\
\>", "Text"],

Cell[BoxData[
    \(NotebookWrite[nb, "\<Hello\>"]\)], "Input"],

Cell[TextData[{
  "NotebookWrite is ultimately much more powerful than StylePrint but it is \
also much lower-level. It does not assume that we want everything in a \
different cell, or that we want it in StandardForm and it allows us to \
specify the output in extreme detail. The drawback of this is that we ",
  StyleBox["must",
    FontWeight->"Bold"],
  " specify things in more detail. While it happily interprets strings, \
characters and digits as if they were keyboard input, it will not accept \
expressions which have a functional structure. For example x^2,  has a \
variety of possible displays; x^2, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(x\^2\),
            "TraditionalForm"], ",", " ", 
          SuperscriptBox[
            StyleBox["x",
              FontSlant->"Plain"], "2"]}], TraditionalForm]]],
  ", or Power[x,2]. We must specify the exact look of the data as well as the \
actual data."
}], "Text"],

Cell[BoxData[
    \(NotebookWrite[nb, x^2]\)], "Input"],

Cell[TextData[{
  "So how do we go about sending this to the notebook? Well if we look at the \
way that the notebook holds ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  " we will see."
}], "Text"],

Cell[BoxData[
    \(x\^2\)], "Input"],

Cell[RawData["\<\
Cell[BoxData[
    SuperscriptBox[\"x\", \"2\"]], \"Input\"]\
\>"], "Input"],

Cell["We can send this box structure.", "Text"],

Cell[BoxData[
    \(NotebookWrite[nb, SuperscriptBox["\<x\>", "\<2\>"]]\)], "Input"],

Cell[TextData[{
  "There are essentially three ways to make this box expression to send.\n1) \
Learn all the details of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " box structure\n2) Create the expression manually and then copy its \
expression\n3) Use MakeBoxes or ToBoxes"
}], "Text"],

Cell["\<\
This is only a one-hour session, so lets skip over option 1. Option 2 is good \
if you know in advance what the expression is going to be like. EG\
\>", "Text"],

Cell[BoxData[
    \(\[Integral]\(1\/\(1 + x\^3\)\) \[DifferentialD]x\)], "Input"],

Cell[RawData["\<\
Cell[BoxData[
    RowBox[{\"\\[Integral]\", 
      RowBox[{
        FractionBox[\"1\", 
          RowBox[{\"1\", \"+\", 
            SuperscriptBox[\"x\", \"3\"]}]], 
        RowBox[{\"\\[DifferentialD]\", \"x\"}]}]}]], \"Input\"]\
\>"], "Input"],

Cell["We can copy this and modify the \"3\" into a parameter", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Do",
        FontColor->RGBColor[0, 0, 1]], 
      StyleBox["[",
        FontColor->RGBColor[0, 0, 1]], 
      RowBox[{
        RowBox[{
          StyleBox["NotebookWrite",
            FontColor->RGBColor[0, 0, 1]], 
          StyleBox["[",
            FontColor->RGBColor[0, 0, 1]], 
          RowBox[{
            StyleBox["nb",
              FontColor->RGBColor[0, 0, 1]], 
            StyleBox[",",
              FontColor->RGBColor[0, 0, 1]], 
            StyleBox["\n",
              FontColor->RGBColor[0, 0, 1]], 
            StyleBox["\t\t",
              FontColor->RGBColor[0, 0, 1]], "\n", "\t\t", "\n", "    ", 
            RowBox[{"RowBox", "[", 
              RowBox[{"{", 
                RowBox[{"\"\<\[Integral]\>\"", ",", " ", "\n", "      ", 
                  RowBox[{"RowBox", "[", 
                    RowBox[{"{", "\n", "        ", 
                      RowBox[{
                        RowBox[{"FractionBox", "[", 
                          RowBox[{"\"\<1\>\"", ",", " ", "\n", "          ", 
                            RowBox[{"RowBox", "[", 
                              RowBox[{"{", 
                                RowBox[{
                                "\"\<1\>\"", ",", " ", "\"\<+\>\"", ",", " ", 
                                  "\n", "            ", 
                                  RowBox[{"SuperscriptBox", "[", 
                                    RowBox[{"\"\<x\>\"", ",", " ", 
                                      StyleBox[\(ToString[i]\),
                                        FontColor->RGBColor[0, 0, 1]]}], "]"}]
                                    }], "}"}], "]"}]}], "]"}], ",", " ", 
                        "\n", "        ", 
                        \(RowBox[{"\<\[DifferentialD]\>", \ "\<x\>"}]\)}], 
                      "}"}], "]"}]}], "}"}], "]"}]}], "\n", "\t", "\n", 
          StyleBox["\t\t",
            FontColor->RGBColor[0, 0, 1]], 
          StyleBox["]",
            FontColor->RGBColor[0, 0, 1]]}], 
        StyleBox[",",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[\({i, 1, 3}\),
          FontColor->RGBColor[0, 0, 1]]}], 
      StyleBox["]",
        FontColor->RGBColor[0, 0, 1]]}]], "Input"],

Cell["\<\
If we do not know the contents in advance, which is quite likely, then we can \
use functions to create boxes from expressions.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToBoxes[x^2]\)], "Input"],

Cell[BoxData[
    \(SuperscriptBox["x", "2"]\)], "Output"]
}, Open  ]],

Cell["\<\
By default it uses StandardForm but we can specify a particular format \
type.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToBoxes[x^\((1/3)\)]\)], "Input"],

Cell[BoxData[
    \(SuperscriptBox["x", RowBox[{"1", "/", "3"}]]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToBoxes[x^\((1/3)\), TraditionalForm]\)], "Input"],

Cell[BoxData[
    \(FormBox[RadicalBox["x", "3"], TraditionalForm]\)], "Output"]
}, Open  ]],

Cell["\<\
Make boxes is essentially the same except that it does not evaluate its \
arguments\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToBoxes[x + 1 + 1]\)], "Input"],

Cell[BoxData[
    \(RowBox[{"2", "+", "x"}]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakeBoxes[x + 1 + 1]\)], "Input"],

Cell[BoxData[
    \(RowBox[{"x", "+", "1", "+", "1"}]\)], "Output"]
}, Open  ]],

Cell["\<\
This can be combined with the various Form functions which we looked at \
earlier\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToBoxes[{{1, 2}, {3, 4}}]\)], "Input"],

Cell[BoxData[
    \(RowBox[{"{", 
        RowBox[{RowBox[{"{", RowBox[{"1", ",", "2"}], "}"}], ",", 
            RowBox[{"{", RowBox[{"3", ",", "4"}], "}"}]}], "}"}]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToBoxes[MatrixForm[{{1, 2}, {3, 4}}]]\)], "Input"],

Cell[BoxData[
    RowBox[{"TagBox", "[", 
      RowBox[{
      \(RowBox[{"(", GridBox[{{"1", "2"}, {"3", "4"}}], ")"}]\), ",", 
        RowBox[{
          TagBox["#1",
            (MatrixForm[ #]&)], "&"}]}], "]"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "For most purposes ",
  StyleBox["ToBoxes[HoldForm[...]]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  " is the same as ",
  StyleBox["MakeBoxes[...]",
    FontFamily->"Courier New",
    FontWeight->"Bold"]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Returning special objects", "Section"],

Cell[CellGroupData[{

Cell["Cells", "Subsubsection"],

Cell["\<\
BoxData, which in practice means typeset expressions, is only one of several \
forms of data that the notebook can hold. For example we might have wanted to \
return a complete, new cell, in the way that StylePrint does. We can send an \
entire cell, exactly as it appears when we unformat it, in the notebook. \
\>", "Text"],

Cell[BoxData[
    \(NotebookWrite[nb, 
      Cell[BoxData[\n\ \ \ \ SuperscriptBox["\<x\>", \ "\<2\>"]], \ 
        "\<Input\>"]]\)], "Input"],

Cell["\<\
We can use this to produce a simple report of input and output of an \
expression. We use MakeBoxes for the input since it holds its argument and \
ToBoxes for the output since it releases its arguments to be evaluated.\
\>", "Text"],

Cell[BoxData[
    \(Do[\t
      NotebookWrite[
        nb, \n\t\t\n\t\tCell[
          BoxData[\(MakeBoxes[
                  \[Integral]\(1\/\(1 + x\^#\)\) \[DifferentialD]x] &\)[i]], 
          "\<Input\>"]\n\t\t\n\t\t]; \n\t
      NotebookWrite[
        nb, \n\t\t\n\t\tCell[
          BoxData[ToBoxes[\[Integral]\(1\/\(1 + x\^i\)\) \[DifferentialD]x]], 
          "\<Output\>"]\n\t\t\n\t\t]\n\t\n\t, {i, 1, 3}]\)], "Input"],

Cell["\<\
We are now in a position to create a useful utility: a version of StylePrint \
with a destination as its first argument:\
\>", "Text"],

Cell[BoxData[{
    \(\(DirectedStylePrint[nb_, expr_String, styledata___] := 
        NotebookWrite[nb, Cell[expr, styledata]];\)\n\), 
    \(\(DirectedStylePrint[nb_, expr_, styledata___] := 
      NotebookWrite[nb, 
        Cell[BoxData[MakeBoxes[expr, StandardForm]], styledata]]; \)\)}], 
  "Input"],

Cell[TextData[{
  "In this example we sent a Cell with two arguments: the contents of the \
cell and its style. The contents were wrapped in a function BoxData which \
tells the front end which rules to apply in formatting the data. All cells \
take the same form; if no data form is specified then the contents are \
assumed to be a simple unformatted string.\n\n",
  StyleBox["Cell[",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["dataform",
    FontFamily->"Courier New",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["[",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["contents",
    FontFamily->"Courier New",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["],\"",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["stylename",
    FontFamily->"Courier New",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["\"]\n\n",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "Here are some possible contents types\nText Cells: ",
  StyleBox["Cell[TextData[",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["text contents",
    FontFamily->"Courier New",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["],\"Text\"]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "\nIf no formatting of the text is required then a simple string can be \
supplied instead of a TextData object\n",
  StyleBox["Cell[\"text contents\",\"Text\"]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "\nTypeset and button cells: ",
  StyleBox["Cell[BoxData[",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["box contents",
    FontFamily->"Courier New",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["],\"Input\"]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "\nGraphics cells: ",
  StyleBox["Cell[GraphicsData[\"",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["graphics format",
    FontFamily->"Courier New",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["\",\"",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["contents",
    FontFamily->"Courier New",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["\"],\"Graphics\"]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "\nCell groups: ",
  StyleBox["Cell[CellGroupData[",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["list of cells contained",
    FontFamily->"Courier New",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["],Open]",
    FontFamily->"Courier New",
    FontWeight->"Bold"]
}], "Text"],

Cell["Lets look at these in practice:", "Text"]
}, Open  ]],

Cell["This is a text cell", "Subsubsection"],

Cell[RawData[
"Cell[\"This is a text cell\", \"Subsubsection\"]"], "Subsubsection"],

Cell["This is a text cell with cell level style changes", "Subsubsection",
  FontColor->GrayLevel[0.330007]],

Cell[RawData["\<\
Cell[\"This is a text cell with cell level style changes\", \
\"Subsubsection\",
  FontColor->GrayLevel[0.33]]\
\>"], "Subsubsection",
  FontColor->GrayLevel[0.330007]],

Cell[TextData[{
  "This is a text cell with internal ",
  StyleBox["style changes",
    FontColor->GrayLevel[0.330007]],
  " "
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[RawData["\<\
Cell[TextData[{
  \"This is a text cell with internal \",
  StyleBox[\"style changes\",
    FontColor->GrayLevel[0.33]],
  \" \"
}], \"Subsubsection\"]\
\>"], "Subsubsection"],

Cell["\<\
For example lets copy this structure into a program and control the option\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Do",
        FontColor->RGBColor[0, 0, 1]], 
      StyleBox["[",
        FontColor->RGBColor[0, 0, 1]], 
      RowBox[{
        RowBox[{
          StyleBox["NotebookWrite",
            FontColor->RGBColor[0, 0, 1]], 
          StyleBox["[",
            FontColor->RGBColor[0, 0, 1]], 
          RowBox[{
            StyleBox["nb",
              FontColor->RGBColor[0, 0, 1]], 
            StyleBox[",",
              FontColor->RGBColor[0, 0, 1]], "\n", "\t\t", "\n", "\t\t", 
            RowBox[{"Cell", "[", 
              RowBox[{
                RowBox[{"TextData", "[", 
                  RowBox[{"{", "\n", "  ", 
                    RowBox[{
                    "\"\<This is a text cell with internal \>\"", ",", "\n", 
                      "  ", 
                      RowBox[{"StyleBox", "[", 
                        RowBox[{"\"\<style changes\>\"", ",", "\n", "    ", 
                          RowBox[{"FontColor", "->", 
                            RowBox[{"RGBColor", "[", 
                              RowBox[{
                                StyleBox["i",
                                  FontColor->RGBColor[0, 0, 1]], ",", " ", 
                                "0", ",", " ", "0"}], "]"}]}]}], "]"}], ",", 
                      "\n", "  ", "\"\< \>\""}], "\n", "}"}], "]"}], ",", 
                " ", "\"\<Subsubsection\>\""}], "]"}]}], "]"}], "\n", "\t", 
        "\n", 
        StyleBox[",",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[\({i, 0, 1, 0.1}\),
          FontColor->RGBColor[0, 0, 1]]}], 
      StyleBox["]",
        FontColor->RGBColor[0, 0, 1]]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Graphics", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(p1 = Show[Graphics[Line[{{0, 0}, {1, 1}}]]]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
.02381 .01472 m
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0007Ool00`00Oomoo`3oOolGOol000Qoo`800?mooaMoo`002Woo0P00
ogoo5Goo000<Ool00`00Oomoo`3oOolBOol000eoo`800?mooa9oo`003goo00<007ooOol0ogoo3goo
000@Ool2003oOol?Ool0019oo`800?moo`eoo`0057oo00<007ooOol0ogoo2Woo000EOol2003oOol:
Ool001Moo`03001oogoo0?moo`Moo`0067oo0P00ogoo1goo000JOol2003oOol5Ool001aoo`03001o
ogoo0?moo`9oo`007Goo0P00ogoo0Woo000OOol2003oOol0025oo`03001oogoo0?aoo`008Woo0P00
o7oo000TOol00`00Oomoo`3iOol002Eoo`800?Uoo`009goo0P00mgoo000YOol00`00Oomoo`3dOol0
02Yoo`800?Aoo`00;7oo0P00lWoo000^Ool00`00Oomoo`3_Ool002moo`800>moo`00<Goo00<007oo
Ool0k7oo000bOol2003/Ool003Aoo`800>Yoo`00=Woo00<007ooOol0igoo000gOol2003WOol003Uo
o`03001oogoo0>Aoo`00>Woo0P00i7oo000lOol2003ROol003ioo`03001oogoo0=moo`00?goo0P00
ggoo0011Ool2003MOol004=oo`03001oogoo0=Yoo`00A7oo0P00fWoo0016Ool00`00Oomoo`3GOol0
04Moo`800=Moo`00BGoo0P00eGoo001;Ool00`00Oomoo`3BOol004aoo`800=9oo`00CWoo0P00d7oo
001@Ool00`00Oomoo`3=Ool0055oo`800<eoo`00Dgoo00<007ooOol0bWoo001DOol2003:Ool005Io
o`800<Qoo`00F7oo00<007ooOol0aGoo001IOol20035Ool005]oo`03001oogoo0<9oo`00G7oo0P00
`Woo001NOol20030Ool0061oo`03001oogoo0;eoo`00HGoo0P00_Goo001SOol2002kOol006Eoo`03
001oogoo0;Qoo`00IWoo0P00^7oo001XOol00`00Oomoo`2eOol006Uoo`800;Eoo`00Jgoo0P00/goo
001]Ool00`00Oomoo`2`Ool006ioo`800;1oo`00L7oo0P00[Woo001bOol00`00Oomoo`2[Ool007=o
o`800:]oo`00MGoo00<007ooOol0Z7oo001fOol2002XOol007Qoo`800:Ioo`00NWoo00<007ooOol0
Xgoo001kOol2002SOol007eoo`03001oogoo0:1oo`00OWoo0P00X7oo0020Ool2002NOol0089oo`03
001oogoo09]oo`00Pgoo0P00Vgoo0025Ool2002IOol008Moo`03001oogoo09Ioo`00R7oo0P00UWoo
002:Ool00`00Oomoo`2COol008]oo`8009=oo`00SGoo0P00TGoo002?Ool00`00Oomoo`2>Ool0091o
o`8008ioo`00TWoo0P00S7oo002DOol00`00Oomoo`29Ool009Eoo`8008Uoo`00Ugoo00<007ooOol0
QWoo002HOol20026Ool009Yoo`8008Aoo`00W7oo00<007ooOol0PGoo002MOol20021Ool009moo`03
001oogoo07ioo`00X7oo0P00OWoo002ROol2001lOol00:Aoo`03001oogoo07Uoo`00YGoo0P00NGoo
002WOol2001gOol00:Uoo`03001oogoo07Aoo`00ZWoo0P00M7oo002/Ool00`00Oomoo`1aOol00:eo
o`80075oo`00[goo0P00Kgoo002aOol00`00Oomoo`1/Ool00;9oo`8006aoo`00]7oo0P00JWoo002f
Ool00`00Oomoo`1WOol00;Moo`8006Moo`00^Goo00<007ooOol0I7oo002jOol2001TOol00;aoo`80
069oo`00_Woo00<007ooOol0Ggoo002oOol2001OOol00<5oo`03001oogoo05aoo`00`Woo0P00G7oo
0034Ool2001JOol00<Ioo`03001oogoo05Moo`00agoo0P00Egoo0039Ool2001EOol00<]oo`03001o
ogoo059oo`00c7oo0P00DWoo003>Ool00`00Oomoo`1?Ool00<moo`8004moo`00dGoo0P00CGoo003C
Ool00`00Oomoo`1:Ool00=Aoo`8004Yoo`00eWoo0P00B7oo003HOol00`00Oomoo`15Ool00=Uoo`80
04Eoo`00fgoo00<007ooOol0@Woo003LOol20012Ool00=ioo`80041oo`00h7oo00<007ooOol0?Goo
003QOol2000mOol00>=oo`03001oogoo03Yoo`00i7oo0P00>Woo003VOol2000hOol00>Qoo`03001o
ogoo03Eoo`00jGoo0P00=Goo003[Ool2000cOol00>eoo`03001oogoo031oo`00kWoo0P00<7oo003`
Ool00`00Oomoo`0]Ool00?5oo`8002eoo`00lgoo0P00:goo003eOol00`00Oomoo`0XOol00?Ioo`80
02Qoo`00n7oo0P009Woo003jOol00`00Oomoo`0SOol00?]oo`8002=oo`00oGoo00<007ooOol087oo
003nOol2000POol00?moo`5oo`8001ioo`00ogoo0goo00<007ooOol06goo003oOol4Ool2000KOol0
0?moo`Ioo`03001oogoo01Qoo`00ogoo1goo0P0067oo003oOol9Ool2000FOol00?moo`]oo`03001o
ogoo01=oo`00ogoo37oo0P004goo003oOol>Ool2000AOol00?mooa1oo`03001oogoo00ioo`00ogoo
4Goo0P003Woo003oOolCOol00`00Oomoo`0;Ool00?mooaAoo`8000]oo`00ogoo5Woo0P002Goo003o
OolHOol00`00Oomoo`06Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0263022, -0.0250053, 
  0.00366761, 0.00593432}}],

Cell[RawData["\<\
Cell[GraphicsData[\"PostScript\", \"\\<\\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
.02381 .01472 m
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\\
\\>\"], \"Graphics\",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0007Ool00`00Oomoo`3oOolGOol000Qoo`800?mooaMoo`002Woo0P00
ogoo5Goo000<Ool00`00Oomoo`3oOolBOol000eoo`800?mooa9oo`003goo00<007ooOol0ogoo3goo
000@Ool2003oOol?Ool0019oo`800?moo`eoo`0057oo00<007ooOol0ogoo2Woo000EOol2003oOol:
Ool001Moo`03001oogoo0?moo`Moo`0067oo0P00ogoo1goo000JOol2003oOol5Ool001aoo`03001o
ogoo0?moo`9oo`007Goo0P00ogoo0Woo000OOol2003oOol0025oo`03001oogoo0?aoo`008Woo0P00
o7oo000TOol00`00Oomoo`3iOol002Eoo`800?Uoo`009goo0P00mgoo000YOol00`00Oomoo`3dOol0
02Yoo`800?Aoo`00;7oo0P00lWoo000^Ool00`00Oomoo`3_Ool002moo`800>moo`00<Goo00<007oo
Ool0k7oo000bOol2003/Ool003Aoo`800>Yoo`00=Woo00<007ooOol0igoo000gOol2003WOol003Uo
o`03001oogoo0>Aoo`00>Woo0P00i7oo000lOol2003ROol003ioo`03001oogoo0=moo`00?goo0P00
ggoo0011Ool2003MOol004=oo`03001oogoo0=Yoo`00A7oo0P00fWoo0016Ool00`00Oomoo`3GOol0
04Moo`800=Moo`00BGoo0P00eGoo001;Ool00`00Oomoo`3BOol004aoo`800=9oo`00CWoo0P00d7oo
001@Ool00`00Oomoo`3=Ool0055oo`800<eoo`00Dgoo00<007ooOol0bWoo001DOol2003:Ool005Io
o`800<Qoo`00F7oo00<007ooOol0aGoo001IOol20035Ool005]oo`03001oogoo0<9oo`00G7oo0P00
`Woo001NOol20030Ool0061oo`03001oogoo0;eoo`00HGoo0P00_Goo001SOol2002kOol006Eoo`03
001oogoo0;Qoo`00IWoo0P00^7oo001XOol00`00Oomoo`2eOol006Uoo`800;Eoo`00Jgoo0P00/goo
001]Ool00`00Oomoo`2`Ool006ioo`800;1oo`00L7oo0P00[Woo001bOol00`00Oomoo`2[Ool007=o
o`800:]oo`00MGoo00<007ooOol0Z7oo001fOol2002XOol007Qoo`800:Ioo`00NWoo00<007ooOol0
Xgoo001kOol2002SOol007eoo`03001oogoo0:1oo`00OWoo0P00X7oo0020Ool2002NOol0089oo`03
001oogoo09]oo`00Pgoo0P00Vgoo0025Ool2002IOol008Moo`03001oogoo09Ioo`00R7oo0P00UWoo
002:Ool00`00Oomoo`2COol008]oo`8009=oo`00SGoo0P00TGoo002?Ool00`00Oomoo`2>Ool0091o
o`8008ioo`00TWoo0P00S7oo002DOol00`00Oomoo`29Ool009Eoo`8008Uoo`00Ugoo00<007ooOol0
QWoo002HOol20026Ool009Yoo`8008Aoo`00W7oo00<007ooOol0PGoo002MOol20021Ool009moo`03
001oogoo07ioo`00X7oo0P00OWoo002ROol2001lOol00:Aoo`03001oogoo07Uoo`00YGoo0P00NGoo
002WOol2001gOol00:Uoo`03001oogoo07Aoo`00ZWoo0P00M7oo002/Ool00`00Oomoo`1aOol00:eo
o`80075oo`00[goo0P00Kgoo002aOol00`00Oomoo`1/Ool00;9oo`8006aoo`00]7oo0P00JWoo002f
Ool00`00Oomoo`1WOol00;Moo`8006Moo`00^Goo00<007ooOol0I7oo002jOol2001TOol00;aoo`80
069oo`00_Woo00<007ooOol0Ggoo002oOol2001OOol00<5oo`03001oogoo05aoo`00`Woo0P00G7oo
0034Ool2001JOol00<Ioo`03001oogoo05Moo`00agoo0P00Egoo0039Ool2001EOol00<]oo`03001o
ogoo059oo`00c7oo0P00DWoo003>Ool00`00Oomoo`1?Ool00<moo`8004moo`00dGoo0P00CGoo003C
Ool00`00Oomoo`1:Ool00=Aoo`8004Yoo`00eWoo0P00B7oo003HOol00`00Oomoo`15Ool00=Uoo`80
04Eoo`00fgoo00<007ooOol0@Woo003LOol20012Ool00=ioo`80041oo`00h7oo00<007ooOol0?Goo
003QOol2000mOol00>=oo`03001oogoo03Yoo`00i7oo0P00>Woo003VOol2000hOol00>Qoo`03001o
ogoo03Eoo`00jGoo0P00=Goo003[Ool2000cOol00>eoo`03001oogoo031oo`00kWoo0P00<7oo003`
Ool00`00Oomoo`0]Ool00?5oo`8002eoo`00lgoo0P00:goo003eOol00`00Oomoo`0XOol00?Ioo`80
02Qoo`00n7oo0P009Woo003jOol00`00Oomoo`0SOol00?]oo`8002=oo`00oGoo00<007ooOol087oo
003nOol2000POol00?moo`5oo`8001ioo`00ogoo0goo00<007ooOol06goo003oOol4Ool2000KOol0
0?moo`Ioo`03001oogoo01Qoo`00ogoo1goo0P0067oo003oOol9Ool2000FOol00?moo`]oo`03001o
ogoo01=oo`00ogoo37oo0P004goo003oOol>Ool2000AOol00?mooa1oo`03001oogoo00ioo`00ogoo
4Goo0P003Woo003oOolCOol00`00Oomoo`0;Ool00?mooaAoo`8000]oo`00ogoo5Woo0P002Goo003o
OolHOol00`00Oomoo`06Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0263022, -0.0250053, 
  0.00366761, 0.00593432}}]
}, Open  ]]
}, Open  ]],

Cell["\<\
The contents of the GraphicsData object are not boxes but PostScript (at the \
moment). So, if we want to create such a cell we need a function which makes \
PostScript, in a simillar way to the use of ToBoxes to make BoxData. We use \
DisplayString. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Short[psdata = DisplayString[p1], 4]\)], "Input"],

Cell[BoxData[
    TagBox[
      \("%!\n%%Creator: Mathematica\n%%AspectRatio: .61803 \nMathPictureStart\
\n/Mabs {\nMgmatrix idtran" \[Ellipsis] 
        "ewpath\n0 g\n.5 Mabswid\n.02381 .01472 m\n.97619 .60332 L\ns\n% End \
of Graphics\nMathPictureEnd\n"\),
      (Short[ #, 4]&)]], "Output"]
}, Open  ]],

Cell["Now we can use this data to make a cell.", "Text"],

Cell[BoxData[
    \(NotebookWrite[nb, 
      Cell[GraphicsData["\<PostScript\>", psdata], "\<Graphics\>"]]\)], 
  "Input"],

Cell["\<\
Here is are two useful utility functions: A function to convert graphics \
objects into cell objects and an alternative DisplayFunction which creates a \
cell in a specified notebook.\
\>", "Text"],

Cell[BoxData[
    \(\(GraphicsToCell[gr_Graphics] := 
      Cell[GraphicsData["\<PostScript\>", DisplayString[gr]], 
        "\<Graphics\>"]; \)\)], "Input"],

Cell[BoxData[
    \(\(DirectedDisplay[nb_NotebookObject]\)[gr_] := 
      \((NotebookWrite[nb, GraphicsToCell[gr]]; gr)\)\)], "Input"],

Cell["Here is the latter in action", "Text"],

Cell[BoxData[
    \(\(Plot[Sin[x], {x, 0, 10}, DisplayFunction -> DirectedDisplay[nb]]; 
    \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Buttons and links", "Subsubsection"],

Cell["\<\
Again, an easy way to create buttons in a program is to create a simple \
example manually and then copy and modify the resulting cell expression into \
a program. Lets create a simple hyperlink palette using the create button \
menu\
\>", "Text"],

Cell[BoxData[GridBox[{
        {
          ButtonBox["Target1",
            ButtonData:>{"Examples.nb", None},
            ButtonStyle->"Hyperlink"]},
        {"Target2"}
        }]], "Input"],

Cell[RawData["\<\
Cell[BoxData[GridBox[{
        {
          ButtonBox[\"Target1\",
            ButtonData:>{\"Examples.nb\", None},
            ButtonStyle->\"Hyperlink\"]},
        {\"Target2\"}
        }]], \"Input\"]\
\>"], "Input"],

Cell["\<\
Firstly, lets copy the way that a single row of the grid containing a single \
button looks.\
\>", "Text"],

Cell[BoxData[
    \(\(MakeHyperlinkRow[target_] := {
        ButtonBox[target, ButtonData :> {target, None}, 
          ButtonStyle -> "\<Hyperlink\>"]}; \)\)], "Input"],

Cell["\<\
Now lets map this function down some data, in this case, the file names found \
in a particular folder, and put the rest of the cell structure around this.\
\>", "Text"],

Cell[BoxData[
    \(NotebookWrite[NotebookCreate[], \t
      Cell[BoxData[\n\ \ \ \ \n\ \ \ \ \ \ StyleBox[
            GridBox[\n\ \ \ \ \ \ \ \ \ \ \ \ Map[MakeHyperlinkRow, 
                FileNames[\ "\<*.nb\>", 
                  "\<C:\\WINDOWS\\Desktop\\\>"]]\n\ \ \ \ \ \ \ \ \ \ \ \ \n\t\
\t\t\t]]], \ "\<Input\>"]\n\t]\)], "Input"],

Cell["\<\
We could polish this report a bit by making the faces of the buttons a little \
more succinct\
\>", "Text"],

Cell[BoxData[
    \(PathToFileName[path_String] := 
      StringDrop[path, First[Last[StringPosition[path, $PathnameSeparator]]]]
        \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PathToFileName["\<C:\\WINDOWS\\Desktop\\ConferenceTalk.nb\>"]\)], 
  "Input"],

Cell[BoxData[
    \("ConferenceTalk.nb"\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(MakeHyperlinkRow[target_] := {
        ButtonBox[PathToFileName[target], ButtonData :> {target, None}, 
          ButtonStyle -> "\<Hyperlink\>"]}; \)\)], "Input"],

Cell["\<\
And by using some of the options available to the notebook and various \
elements. A full list of these options can be found in the option \
inspector.\
\>", "Text"],

Cell[BoxData[
    RowBox[{"NotebookWrite", "[", 
      RowBox[{
      \(NotebookCreate[StyleDefinitions -> "\<Classroom.nb\>"]\), ",", "\t", 
        "\n", "\t", 
        RowBox[{"Cell", "[", 
          RowBox[{
            RowBox[{"BoxData", "[", "\n", "    ", "\n", "      ", 
              RowBox[{"StyleBox", "[", 
                RowBox[{"GridBox", "[", "\n", "            ", 
                  RowBox[{
                  \(Map[MakeHyperlinkRow, 
                      FileNames[\ "\<*.nb\>", 
                        "\<C:\\WINDOWS\\Desktop\\\>"]]\), "\n", 
                    "            ", "\n", "\t\t\t\t", 
                    StyleBox[",",
                      FontColor->RGBColor[0, 0, 1]], 
                    StyleBox[\(RowSpacings -> 0\),
                      FontColor->RGBColor[0, 0, 1]], 
                    StyleBox[",",
                      FontColor->RGBColor[0, 0, 1]], 
                    StyleBox[\(GridFrame -> True\),
                      FontColor->RGBColor[0, 0, 1]]}], "]"}], "]"}], "]"}], 
            ",", " ", "\"\<Input\>\""}], "]"}]}], "\n", "\t", "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Notebooks", "Subsubsection"],

Cell[TextData[{
  "NotebookWrite will always send the data to the position of the current \
selection in the specified notebook. There are several ways to alter this \
selection including SelectionMove and NotebookFollow, which we do not have \
time to examine here. \nOne concern might be that mouse clicks on the report \
as it is being created will change the current selection and so alter the \
order of the report. It also places some restrictions on our programming \
style as the report must either be created in order, top to bottom, or we \
must start moving the selection around: a potentially confusing issue.\nThe \
solution is to create the entire notebook before displaying any of it. In the \
same way as a Cell has a functional description, so does the notebook. It is \
simply ",
  StyleBox["Notebook[",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["ListOfCells",
    FontFamily->"Courier New",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["Options",
    FontFamily->"Courier New",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  ".\nLets look at a new example and make use of everything we have learned. \
Here is a set of data:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(!! "\<C:\\WINDOWS\\Desktop\\Answers.txt\>"\)\)], "Input"],

Cell["\<\
Jon\t2\t5\t1\t2\t5\t4
Bob\t1\t4\t1\t4\t2\t4
Jane\t5\t1\t4\t2\t2\t5
Roger\t5\t1\t5\t3\t5\t4
Conrad\t4\t3\t1\t1\t1\t5
William\t5\t2\t1\t1\t2\t4
Rachel\t4\t1\t4\t1\t3\t3
Alan\t1\t5\t4\t5\t5\t1
Kate\t4\t4\t1\t3\t1\t3
Fiona\t1\t5\t5\t3\t5\t2
Warren\t5\t3\t3\t5\t3\t1\
\>", "Print"]
}, Open  ]],

Cell["\<\
It is the answers given by a class in a multiple choice test. Here Warren \
gave answer 5 to question 1, 3 to question 2 etc.\
\>", "Text"],

Cell[BoxData[
    \(<< Graphics`Graphics`\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Preparing the data", "Subsubsection"],

Cell["\<\
First of all we define two commands. MarkOneTest takes a particular students \
answers and converts it into a list of True's and False's by comparing them \
to a set of \"Correct\" answers. The second command imports the data and \
applies this marking function to each student before calling the MakeReport \
function.\
\>", "Text"],

Cell[BoxData[{
    \(\(MarkOneTest[data_, correct_] := 
        Prepend[MapThread[Equal, {Rest[data], correct}], \ First[data]];\)\n
    \), 
    \(\(AnalyseResults[datafile_, correct_] := 
      MakeReport[\n\t\tMap[
          MarkOneTest[#, correct] &, \n\t\t\tReadList[datafile, Word, 
            RecordLists -> True]\n\t\t]]; \)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Preparing the report", "Subsubsection"],

Cell["\<\
Now, our report will consist of two parts. The first part will be a report on \
how many students got each question right. This will be a Cell with the words \
\"Question Summary\" followed by a cell with a BarChart in. These will be \
grouped together with a closed CellGroup.\
\>", "Text"],

Cell[BoxData[
    \(\(QuestionReport[data_] := 
      Cell[CellGroupData[{\n\t\t\t\t\n\t\t\t\t
            Cell["\<Questions Summary\>", "\<Section\>"], \n\t\t\t\t\n\t\t\t\t
            GraphicsToCell[
              BarChart[Map[Count[#, True]&, data], 
                DisplayFunction -> Identity]\n\t\t\t\t\t\n\t\t\t\t]}, 
          Closed]]; \)\)], "Input"],

Cell["\<\
The second part will be a report on each student. This will give the students \
name followed by a PieChart showing how many answers they got right. These \
two cells are grouped with a CellGroup which is closed.\
\>", "Text"],

Cell[BoxData[
    \(\(\(OneStudentReport[{student_, answers__}] := 
      Cell[CellGroupData[{\n\t\t\t\t\n\t\t\t\tCell[student, "\<Section\>"], \n
            \t\t\t\t\n\t\t\t\t
            GraphicsToCell[\n\t\t\t\t\t\t
              PieChart[{Count[{answers}, True], Count[{answers}, False]}, 
                PieLabels -> {"\<Correct\>", "\<Wrong\>"}, 
                DisplayFunction -> Identity]]\n\t\t\t\n\t\t\t}, Closed]]; \)\t
    \)\)], "Input"],

Cell["\<\
Finally, we create a notebook with a heading cell, the question report and a \
list of student reports, one for each student. We will ask for this notebook \
to be in the \"Report\" style.\
\>", "Text"],

Cell[BoxData[
    \(MakeReport[data_] := 
      NotebookPut[\n\t\tNotebook[\n\t\t\t\t\t\t\t{Cell[
                "\<Multiple Choice Test Results\>", "\<Title\>", 
                CellFrame -> {{0, 0}, {4, 0}}], 
              QuestionReport[Rest[Transpose[data]]]}\n\t\t\t\t\t~
            Join~\n\t\t\tMap[OneStudentReport, 
              data], \n\t\t\t\t\tStyleDefinitions -> "\<Report.nb\>"]]\)], 
  "Input"],

Cell["All that remains is for us to use this report function.", "Text"],

Cell[BoxData[
    \(AnalyseResults["\<C:\\WINDOWS\\Desktop\\Answers.txt\>", 
      {"\<2\>", "\<5\>", "\<2\>", "\<1\>", "\<3\>", "\<2\>"}]\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 800}, {0, 544}},
ScreenStyleEnvironment->"Presentation",
WindowSize->{740, 446},
WindowMargins->{{2, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {
    Cell[ "Automatic Report Generation", "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\

Modify the definitions below to change the default appearance of all cells in \

a given style.  Make modifications to any definition using commands in the 
Format menu.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\

The options defined for the style below will be used at the Notebook level.
\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{40, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    PageWidth->800,
    CellMargins->{{0, 0}, {5, 0}},
    CellFrameMargins->{{100, 20}, {8, 20}},
    AutoIndent->False,
    LineSpacing->{0, 44},
    FontSize->40,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.812512, 0, 0]],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{40, 10}, {12, 30}},
    FontSize->24]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{40, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{100, Inherited}, {10, 5}},
    AutoIndent->False,
    LineSpacing->{0, 34},
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{40, 10}, {12, 8}},
    FontSize->18]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{100, Inherited}, {20, 0}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{100, 10}, {20, 0}},
    CellFrameMargins->2,
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Author", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{40, 10}, {12, 8}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellDingbat->None,
    CellMargins->{{33, 10}, {11, 0}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellDingbat->None,
    CellMargins->{{33, 0}, {7, 22}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{33, 10}, {0, 4}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Rule"],
    CellMargins->{{22, Inherited}, {8, 18}},
    PageBreakBelow->False],
  
  Cell[StyleData["Rule", "Presentation"],
    CellFrame->{{0, 0}, {3, 0}},
    CellMargins->{{33, 10}, {0, 40}},
    CellFrameMargins->False,
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Rule", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Rule", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{33, 10}, {10, 10}},
    LineSpacing->{1, 1},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\

The cells in this section define styles used for input and output to the 
kernel.  Be careful when modifying, renaming, or removing these styles, 
because the front end associates special meanings with these style names. 
Some attributes for these styles are actually set in FormatType Styles (in 
the last section of this stylesheet). 
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16,
    Background->RGBColor[0.996109, 0.996109, 0.500008]],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Open  ]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16,
    Background->GrayLevel[0.750011]],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9,
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\

The cells below define styles useful for making hypertext ButtonBoxes.  The 
\"Hyperlink\" style is for links within the same Notebook, or between 
Notebooks.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\

The following styles are for linking automatically to the on-line help 
system.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\

The cells below define styles that define standard ButtonFunctions, for use 
in palette buttons.
\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\

The cells below define styles useful for making placeholder objects in 
palette templates.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    Placeholder->Primary,
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Condensed"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\

The cells below define styles that are mixed in with the styles of most 
cells.  If a cell's FormatType matches the name of one of the styles defined 
below, then that style is applied between the cell's style and its own 
options. This is particularly true of Input and Output.
\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\

The style defined below is mixed in to any cell that is in an inline cell 
within another.
\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Expression Annotation Styles", "Section"],
  
  Cell["\<\

The cells below define styles that are used to effect the display of certain 
types of objects in typeset expressions.  For example, \"UnmatchedBracket\" 
style defines how unmatched bracket, curly bracket, and parenthesis 
characters are displayed (typically by coloring them to  

make them stand out).
\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    FontColor->RGBColor[0.760006, 0.330007, 0.8]]
  }, Closed]]
  }, Open  ]]
  }]
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 44, 0, 77, "Title"],
Cell[1778, 53, 61, 3, 64, "Author"],
Cell[1842, 58, 600, 13, 167, "Text"],

Cell[CellGroupData[{
Cell[2467, 75, 33, 0, 40, "Section"],

Cell[CellGroupData[{
Cell[2525, 79, 100, 4, 58, "Subsubsection"],
Cell[2628, 85, 315, 9, 62, "Text"],

Cell[CellGroupData[{
Cell[2968, 98, 38, 1, 54, "Input"],
Cell[3009, 101, 35, 1, 54, "Output"]
}, Open  ]],
Cell[3059, 105, 381, 8, 83, "Text"],
Cell[3443, 115, 50, 1, 54, "Input"],
Cell[3496, 118, 57, 0, 41, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3590, 123, 58, 0, 57, "Subsubsection"],
Cell[3651, 125, 129, 3, 41, "Text"],
Cell[3783, 130, 62, 1, 54, "Input"],
Cell[3848, 133, 68, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[3941, 137, 65, 1, 54, "Input"],
Cell[4009, 140, 58, 1, 54, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4116, 147, 41, 0, 57, "Subsubsection"],
Cell[4160, 149, 74, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[4259, 153, 56, 1, 54, "Input"],
Cell[4318, 156, 12515, 417, 186, 4488, 313, "GraphicsData", 
"PostScript", "Graphics"],
Cell[16836, 575, 130, 3, 54, "Output"]
}, Open  ]],
Cell[16981, 581, 313, 5, 83, "Text"],
Cell[17297, 588, 17788, 501, 322, 8223, 378, "GraphicsData", 
"PostScript", "Graphics"],
Cell[35088, 1091, 330, 6, 104, "Text"],
Cell[35421, 1099, 365, 6, 192, "Input"],
Cell[35789, 1107, 88, 2, 41, "Text"],

Cell[CellGroupData[{
Cell[35902, 1113, 63, 1, 54, "Input"],

Cell[CellGroupData[{
Cell[35990, 1118, 6976, 270, 133, 2997, 216, "GraphicsData", 
"PostScript", "Graphics"],
Cell[42969, 1390, 9694, 373, 144, 4157, 300, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[52678, 1766, 54, 1, 54, "Output"],
Cell[52735, 1769, 86, 1, 54, "Output"],
Cell[52824, 1772, 9414, 374, 137, 4256, 306, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[62253, 2149, 399, 6, 104, "Text"],
Cell[62655, 2157, 1178, 22, 238, "Input"],

Cell[CellGroupData[{
Cell[63858, 2183, 63, 1, 54, "Input"],
Cell[63924, 2186, 54, 1, 54, "Output"],
Cell[63981, 2189, 86, 1, 54, "Output"],
Cell[64070, 2192, 9317, 373, 134, 4256, 306, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[73448, 2572, 34, 0, 40, "Section"],
Cell[73485, 2574, 548, 9, 146, "Text"],
Cell[74036, 2585, 1029, 21, 237, "Output"],
Cell[75068, 2608, 49, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[75142, 2612, 43, 0, 57, "Subsubsection"],
Cell[75188, 2614, 69, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[75282, 2618, 37, 1, 54, "Input"],
Cell[75322, 2621, 44, 1, 54, "Output"]
}, Open  ]],
Cell[75381, 2625, 87, 2, 41, "Text"],

Cell[CellGroupData[{
Cell[75493, 2631, 66, 1, 54, "Input"],
Cell[75562, 2634, 174, 5, 54, "Output"]
}, Open  ]],
Cell[75751, 2642, 46, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[75822, 2646, 97, 2, 54, "Input"],
Cell[75922, 2650, 198, 5, 54, "Output"]
}, Open  ]],
Cell[76135, 2658, 202, 4, 62, "Text"],

Cell[CellGroupData[{
Cell[76362, 2666, 146, 2, 77, "Input"],
Cell[76511, 2670, 256, 6, 54, "Output"]
}, Open  ]],
Cell[76782, 2679, 240, 4, 62, "Text"],

Cell[CellGroupData[{
Cell[77047, 2687, 56, 1, 54, "Input"],
Cell[77106, 2690, 161, 5, 55, "Output"]
}, Open  ]],
Cell[77282, 2698, 53, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[77360, 2702, 65, 1, 54, "Input"],
Cell[77428, 2705, 991, 14, 169, "Output"]
}, Open  ]],
Cell[78434, 2722, 60, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[78519, 2726, 49, 1, 54, "Input"],
Cell[78571, 2729, 1277, 22, 149, "Output"]
}, Open  ]],
Cell[79863, 2754, 172, 3, 62, "Text"],

Cell[CellGroupData[{
Cell[80060, 2761, 64, 1, 54, "Input"],
Cell[80127, 2764, 4790, 120, 149, "Output"]
}, Open  ]],
Cell[84932, 2887, 104, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[85061, 2894, 247, 4, 100, "Input"],
Cell[85311, 2900, 1668, 29, 171, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[87028, 2935, 47, 0, 57, "Subsubsection"],
Cell[87078, 2937, 37, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[87140, 2941, 69, 1, 54, "Input"],
Cell[87212, 2944, 121, 2, 87, "Output"]
}, Open  ]],
Cell[87348, 2949, 186, 4, 62, "Text"],

Cell[CellGroupData[{
Cell[87559, 2957, 54, 1, 54, "Input"],
Cell[87616, 2960, 159, 3, 92, "Output"]
}, Open  ]],
Cell[87790, 2966, 376, 10, 83, "Text"],

Cell[CellGroupData[{
Cell[88191, 2980, 48, 1, 54, "Input"],
Cell[88242, 2983, 96, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[88375, 2990, 49, 1, 54, "Input"],
Cell[88427, 2993, 323, 8, 99, "Output"]
}, Open  ]],
Cell[88765, 3004, 109, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[88899, 3011, 46, 1, 54, "Input"],
Cell[88948, 3014, 162, 3, 88, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[89147, 3022, 50, 1, 54, "Input"],
Cell[89200, 3025, 116, 3, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[89353, 3033, 44, 1, 54, "Input"],
Cell[89400, 3036, 109, 3, 70, "Output"]
}, Open  ]],
Cell[89524, 3042, 196, 4, 62, "Text"],

Cell[CellGroupData[{
Cell[89745, 3050, 55, 1, 56, "Input"],
Cell[89803, 3053, 279, 6, 78, "Output"]
}, Open  ]],
Cell[90097, 3062, 103, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[90225, 3069, 48, 1, 54, "Input"],
Cell[90276, 3072, 63, 2, 54, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[90400, 3081, 33, 0, 40, "Section"],
Cell[90436, 3083, 280, 5, 83, "Text"],

Cell[CellGroupData[{
Cell[90741, 3092, 50, 0, 57, "Subsubsection"],
Cell[90794, 3094, 214, 4, 62, "Text"],

Cell[CellGroupData[{
Cell[91033, 3102, 230, 4, 100, "Input"],
Cell[91266, 3108, 192, 7, 77, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[91507, 3121, 36, 0, 35, "Subsubsection"],
Cell[91546, 3123, 467, 10, 104, "Text"],
Cell[92016, 3135, 69, 1, 54, "Input"],
Cell[92088, 3138, 185, 4, 62, "Text"],
Cell[92276, 3144, 178, 3, 77, "Input"],
Cell[92457, 3149, 133, 3, 41, "Text"],
Cell[92593, 3154, 63, 1, 54, "Input"],
Cell[92659, 3157, 76, 0, 41, "Text"],
Cell[92738, 3159, 97, 2, 54, "Input"],
Cell[92838, 3163, 104, 3, 41, "Text"],
Cell[92945, 3168, 1249, 24, 261, "Input"],
Cell[94197, 3194, 63, 1, 54, "Input"],
Cell[94263, 3197, 386, 8, 146, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[94698, 3211, 35, 0, 40, "Section"],
Cell[94736, 3213, 46, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[94807, 3217, 51, 1, 54, "Input"],
Cell[94861, 3220, 309, 4, 120, "Print"]
}, Open  ]],
Cell[95185, 3227, 105, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[95315, 3234, 54, 1, 54, "Input"],
Cell[95372, 3237, 231, 6, 54, "Output"]
}, Open  ]],
Cell[95618, 3246, 149, 3, 62, "Text"],
Cell[95770, 3251, 124, 3, 77, "Input"],
Cell[95897, 3256, 300, 5, 83, "Text"],

Cell[CellGroupData[{
Cell[96222, 3265, 45, 1, 54, "Input"],
Cell[96270, 3268, 221, 6, 54, "Output"]
}, Open  ]],
Cell[96506, 3277, 70, 0, 41, "Text"],
Cell[96579, 3279, 712, 17, 135, "Text"],
Cell[97294, 3298, 106, 3, 41, "Text"],
Cell[97403, 3303, 63, 1, 54, "Input"],
Cell[97469, 3306, 956, 21, 146, "Text"],
Cell[98428, 3329, 55, 1, 54, "Input"],
Cell[98486, 3332, 207, 6, 62, "Text"],
Cell[98696, 3340, 37, 1, 56, "Input"],
Cell[98736, 3343, 93, 3, 58, "Input"],
Cell[98832, 3348, 47, 0, 41, "Text"],
Cell[98882, 3350, 84, 1, 54, "Input"],
Cell[98969, 3353, 300, 7, 104, "Text"],
Cell[99272, 3362, 170, 3, 62, "Text"],
Cell[99445, 3367, 81, 1, 71, "Input"],
Cell[99529, 3370, 264, 8, 143, "Input"],
Cell[99796, 3380, 70, 0, 41, "Text"],
Cell[99869, 3382, 2229, 51, 286, "Input"],
Cell[102101, 3435, 151, 3, 62, "Text"],

Cell[CellGroupData[{
Cell[102277, 3442, 45, 1, 54, "Input"],
Cell[102325, 3445, 58, 1, 54, "Output"]
}, Open  ]],
Cell[102398, 3449, 102, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[102525, 3456, 53, 1, 54, "Input"],
Cell[102581, 3459, 78, 1, 54, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[102696, 3465, 70, 1, 54, "Input"],
Cell[102769, 3468, 80, 1, 54, "Output"]
}, Open  ]],
Cell[102864, 3472, 107, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[102996, 3479, 51, 1, 54, "Input"],
Cell[103050, 3482, 57, 1, 54, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[103144, 3488, 53, 1, 54, "Input"],
Cell[103200, 3491, 67, 1, 54, "Output"]
}, Open  ]],
Cell[103282, 3495, 105, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[103412, 3502, 58, 1, 54, "Input"],
Cell[103473, 3505, 179, 3, 77, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[103689, 3513, 70, 1, 54, "Input"],
Cell[103762, 3516, 226, 6, 54, "Output"]
}, Open  ]],
Cell[104003, 3525, 250, 9, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[104290, 3539, 44, 0, 40, "Section"],

Cell[CellGroupData[{
Cell[104359, 3543, 30, 0, 57, "Subsubsection"],
Cell[104392, 3545, 335, 5, 83, "Text"],
Cell[104730, 3552, 142, 3, 77, "Input"],
Cell[104875, 3557, 243, 4, 62, "Text"],
Cell[105121, 3563, 427, 10, 364, "Input"],
Cell[105551, 3575, 144, 3, 41, "Text"],
Cell[105698, 3580, 303, 6, 169, "Input"],
Cell[106004, 3588, 2656, 86, 295, "Text"],
Cell[108663, 3676, 47, 0, 41, "Text"]
}, Open  ]],
Cell[108725, 3679, 44, 0, 57, "Subsubsection"],
Cell[108772, 3681, 83, 1, 41, "Subsubsection"],
Cell[108858, 3684, 108, 1, 57, "Subsubsection"],
Cell[108969, 3687, 186, 5, 58, "Subsubsection"],
Cell[109158, 3694, 147, 5, 57, "Subsubsection"],

Cell[CellGroupData[{
Cell[109330, 3703, 193, 7, 126, "Subsubsection"],
Cell[109526, 3712, 98, 2, 41, "Text"],
Cell[109627, 3716, 1653, 40, 261, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[111317, 3761, 33, 0, 57, "Subsubsection"],

Cell[CellGroupData[{
Cell[111375, 3765, 82, 1, 54, "Input"],

Cell[CellGroupData[{
Cell[111482, 3770, 4203, 89, 186, 647, 41, "GraphicsData", 
"PostScript", "Graphics"],
Cell[115688, 3861, 4346, 94, 789, 0, 0, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[120061, 3959, 275, 5, 83, "Text"],

Cell[CellGroupData[{
Cell[120361, 3968, 69, 1, 54, "Input"],
Cell[120433, 3971, 293, 6, 353, "Output"]
}, Open  ]],
Cell[120741, 3980, 56, 0, 41, "Text"],
Cell[120800, 3982, 122, 3, 77, "Input"],
Cell[120925, 3987, 207, 4, 62, "Text"],
Cell[121135, 3993, 157, 3, 100, "Input"],
Cell[121295, 3998, 134, 2, 77, "Input"],
Cell[121432, 4002, 44, 0, 41, "Text"],
Cell[121479, 4004, 108, 2, 54, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[121624, 4011, 42, 0, 57, "Subsubsection"],
Cell[121669, 4013, 257, 5, 83, "Text"],
Cell[121929, 4020, 192, 6, 75, "Input"],
Cell[122124, 4028, 236, 8, 59, "Input"],
Cell[122363, 4038, 116, 3, 41, "Text"],
Cell[122482, 4043, 169, 3, 100, "Input"],
Cell[122654, 4048, 179, 3, 62, "Text"],
Cell[122836, 4053, 341, 6, 215, "Input"],
Cell[123180, 4061, 117, 3, 41, "Text"],
Cell[123300, 4066, 151, 3, 100, "Input"],

Cell[CellGroupData[{
Cell[123476, 4073, 97, 2, 54, "Input"],
Cell[123576, 4077, 53, 1, 54, "Output"]
}, Open  ]],
Cell[123644, 4081, 185, 3, 100, "Input"],
Cell[123832, 4086, 175, 4, 62, "Text"],
Cell[124010, 4092, 1107, 23, 261, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[125154, 4120, 34, 0, 57, "Subsubsection"],
Cell[125191, 4122, 1346, 31, 231, "Text"],

Cell[CellGroupData[{
Cell[126562, 4157, 79, 1, 54, "Input"],
Cell[126644, 4160, 286, 12, 206, "Print"]
}, Open  ]],
Cell[126945, 4175, 149, 3, 62, "Text"],
Cell[127097, 4180, 54, 1, 54, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[127188, 4186, 43, 0, 57, "Subsubsection"],
Cell[127234, 4188, 343, 6, 83, "Text"],
Cell[127580, 4196, 347, 7, 192, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[127964, 4208, 45, 0, 57, "Subsubsection"],
Cell[128012, 4210, 301, 5, 83, "Text"],
Cell[128316, 4217, 360, 7, 238, "Input"],
Cell[128679, 4226, 236, 4, 62, "Text"],
Cell[128918, 4232, 453, 8, 284, "Input"],
Cell[129374, 4242, 212, 4, 62, "Text"],
Cell[129589, 4248, 413, 8, 215, "Input"],
Cell[130005, 4258, 71, 0, 41, "Text"],
Cell[130079, 4260, 151, 2, 77, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

